@@ -57,6 +57,7 @@ typedef struct _FitPeak
     int *region_end;
     int *cumul_region;
     int method;
+    Bool *dim_done;
 }   FitPeak;
 
 Peak new_peak(int ndim)
@@ -132,8 +133,7 @@ CcpnStatus set_text_peak(Peak peak, CcpnString text, CcpnString error_msg)
 
 void set_position_peak(Peak peak, float *position)
 {
-    FREE(peak->position, float);
-    peak->position = position;
+    COPY_VECTOR(peak->position, position, peak->ndim);
 }
 
 void set_text_offset_peak(Peak peak, int dim, float text_offset)
@@ -154,8 +154,7 @@ void reset_text_offset_peak(Peak peak, int dim)
 
 void set_num_aliasing_peak(Peak peak, int *num_aliasing)
 {
-    FREE(peak->num_aliasing, int);
-    peak->num_aliasing = num_aliasing;
+    COPY_VECTOR(peak->num_aliasing, num_aliasing, peak->ndim);
 }
 
 /* xpix, ypix are points per pixel */
@@ -602,71 +601,83 @@ void set_quality_peak(Peak peak, float quality)
 }
 */
 
-static float gaussian(int ndim, int *x, float *a, float *dy_da)
+static float gaussian(int ndim, int ndim_done, Bool *dim_done, int *x, float *a, float *dy_da)
 {
-    float h = a[0], *position = a+1, *linewidth = a+1+ndim;
+    float h = a[0], *position = a+1, *linewidth = a+1+ndim_done;
     float *dy_dh, *dy_dp, *dy_dl;
     float lw, dx, y = h;
-    int i;
+    int i, j;
 
     if (dy_da)
     {
         dy_dh = dy_da;
         dy_dp = dy_da+1;
-        dy_dl = dy_da+1+ndim;
+        dy_dl = dy_da+1+ndim_done;
     }
 
+    j = 0;
     for (i = 0; i < ndim; i++)
     {
-        dx = x[i] - position[i];
-        lw = linewidth[i];
-        y *= exp(-4*log(2)*dx*dx/(lw*lw));
-        if (dy_da)
-        {
-            dy_dp[i] = 8*log(2)*dx/(lw*lw);
-            dy_dl[i] = 8*log(2)*dx*dx/(lw*lw*lw);
-        }
+	if (dim_done[i])
+	{
+            dx = x[i] - position[j];
+            lw = linewidth[j];
+            y *= exp(-4*log(2)*dx*dx/(lw*lw));
+            if (dy_da)
+            {
+                dy_dp[j] = 8*log(2)*dx/(lw*lw);
+                dy_dl[j] = 8*log(2)*dx*dx/(lw*lw*lw);
+            }
+
+	    j++;
+	}
     }
 
     if (dy_da)
     {
         *dy_dh = y / h;
-        SCALE_VECTOR(dy_dp, dy_dp, y, ndim);
-        SCALE_VECTOR(dy_dl, dy_dl, y, ndim);
+        SCALE_VECTOR(dy_dp, dy_dp, y, ndim_done);
+        SCALE_VECTOR(dy_dl, dy_dl, y, ndim_done);
     }
 
     return y;
 }
 
-static float lorentzian(int ndim, int *x, float *a, float *dy_da)
+static float lorentzian(int ndim, int ndim_done, Bool *dim_done, int *x, float *a, float *dy_da)
 {
-    float h = a[0], *position = a+1, *linewidth = a+1+ndim;
+    float h = a[0], *position = a+1, *linewidth = a+1+ndim_done;
     float *dy_dh, *dy_dp, *dy_dl;
     float lw, dx, d, y = h;
-    int i;
+    int i, j;
 
     if (dy_da)
     {
         dy_dh = dy_da;
         dy_dp = dy_da+1;
-        dy_dl = dy_da+1+ndim;
+        dy_dl = dy_da+1+ndim_done;
     }
 
+    j = 0;
     for (i = 0; i < ndim; i++)
     {
-        dx = x[i] - position[i];
-        lw = linewidth[i];
-        d = lw*lw+4*dx*dx;
-        y *= lw*lw/d;
-        dy_dp[i] = 8*dx/d;
-        dy_dl[i] = 8*dx*dx/(lw*d);
+	if (dim_done[i])
+	{
+            dx = x[i] - position[j];
+            lw = linewidth[j];
+            d = lw*lw+4*dx*dx;
+            y *= lw*lw/d;
+            dy_dp[j] = 8*dx/d;
+            dy_dl[j] = 8*dx*dx/(lw*d);
+
+	    j++;
+	}
     }
 
     if (dy_da)
     {
         *dy_dh = y / h;
-        SCALE_VECTOR(dy_dp, dy_dp, y, ndim);
-        SCALE_VECTOR(dy_dl, dy_dl, y, ndim);
+        SCALE_VECTOR(dy_dp, dy_dp, y, ndim_done);
+        SCALE_VECTOR(dy_dl, dy_dl, y, ndim_done);
     }
 
     return y;
@@ -681,8 +692,9 @@ static void _fitting_func(float xind, float *a, float *y_fit, float *dy_da, void
     int *region_end = fitPeak->region_end;
     int *cumul_region = fitPeak->cumul_region;
     int method = fitPeak->method;
+    Bool *dim_done = fitPeak->dim_done;
     int ind = NEAREST_INTEGER(xind);
-    int nparams_per_peak = 1 + 2*ndim;
+    int nparams_per_peak, ndim_done;
     int i, j, x[MAX_NDIM];
     float *position = a+1;
 
@@ -692,21 +704,35 @@ static void _fitting_func(float xind, float *a, float *y_fit, float *dy_da, void
     // check whether position is outside the intended fitting region
     for (i = 0; i < ndim; i++)
     {
-        if ((position[i] < region_offset[i]) || (position[i] >= region_end[i]))
-        {
-            *y_fit = LARGE_NUMBER;
-            ZERO_VECTOR(dy_da, npeaks*nparams_per_peak); // arbitrary, hopefully ok
-            return;
-        }
+	if (dim_done[i])
+	{
+            if ((position[i] < region_offset[i]) || (position[i] >= region_end[i]))
+            {
+                *y_fit = LARGE_NUMBER;
+                ZERO_VECTOR(dy_da, npeaks*nparams_per_peak); // arbitrary, hopefully ok
+                return;
+            }
+	}
+    }
+
+    nparams_per_peak = 1;
+    ndim_done = 0;
+    for (i = 0; i < ndim; i++)
+    {
+        if (dim_done[i])
+	{
+            ndim_done++;
+            nparams_per_peak += 2;
+	}
     }
 
     *y_fit = 0;
     for (j = 0; j < npeaks; j++)
     {
         if (method == GAUSSIAN_METHOD)
-            *y_fit += gaussian(ndim, x, a, dy_da);
+            *y_fit += gaussian(ndim, ndim_done, dim_done, x, a, dy_da);
         else
-            *y_fit += lorentzian(ndim, x, a, dy_da);
+            *y_fit += lorentzian(ndim, ndim_done, dim_done, x, a, dy_da);
 
         a += nparams_per_peak;
         if (dy_da)
@@ -755,9 +781,9 @@ printf("first[%d] = %d\n", i, first[i]);
 	    return CCPN_ERROR;
 	}
 
-	if (last[i] >= block_file->points[i])
+	if (last[i] > block_file->points[i])
 	{
-	    sprintf(error_msg, "last[%d] = %d >= %d = npts", i, first[i], block_file->points[i]);
+	    sprintf(error_msg, "last[%d] = %d > %d = npts", i, last[i], block_file->points[i]);
 	    return CCPN_ERROR;
 	}
     }
@@ -816,6 +842,7 @@ printf("PARAM %d before: %f\n", i, params[i]);
     fitPeak.region_end = last;
     fitPeak.cumul_region = cumul_region;
     fitPeak.method = method;
+    fitPeak.dim_done = dim_done;
 
     status = nonlinear_fit(total_region_size, x, y, w, y_fit,
                 nparams, params, params_dev,
