@@ -65,9 +65,12 @@ static void draw_circle(float x, float y, float xscale, float yscale,
 {
     static float r = 1;
     float dx = r*xscale, dy = r*yscale;
+/*
     float dr = MIN(dx, dy);
 
     (drawing_funcs->draw_circle)(data, x, y, dr);
+*/
+    (drawing_funcs->draw_ellipse)(data, x, y, dx, dy);
 }
 
 static void draw_disk(float x, float y, float xscale, float yscale,
@@ -75,9 +78,12 @@ static void draw_disk(float x, float y, float xscale, float yscale,
 {
     static float r = 1;
     float dx = r*xscale, dy = r*yscale;
+/*
     float dr = MIN(dx, dy);
 
     (drawing_funcs->fill_circle)(data, x, y, dr);
+*/
+    (drawing_funcs->fill_ellipse)(data, x, y, dx, dy);
 }
 
 static void draw_box(float x, float y, float xscale, float yscale,
