@@ -273,11 +273,21 @@ static void gl_fill_circle(Generic_ptr data, float x, float y, float r)
     fill_circle_gl_handler((Gl_handler) data, x, y, r);
 }
 
+static void gl_fill_ellipse(Generic_ptr data, float x, float y, float rx, float ry)
+{
+    fill_ellipse_gl_handler((Gl_handler) data, x, y, rx, ry);
+}
+
 static void gl_draw_circle(Generic_ptr data, float x, float y, float r)
 {
     draw_circle_gl_handler((Gl_handler) data, x, y, r);
 }
 
+static void gl_draw_ellipse(Generic_ptr data, float x, float y, float rx, float ry)
+{
+    draw_ellipse_gl_handler((Gl_handler) data, x, y, rx, ry);
+}
+
 static void gl_get_background(Generic_ptr data, float *color)
 {
     Gl_handler_p gl_handler_p = (Gl_handler_p) data;
@@ -307,9 +317,9 @@ static Drawing_funcs drawing_funcs = { SCREEN_DRAWING,
 	gl_draw_line, gl_draw_clipped_line,
 	gl_draw_polyline, gl_draw_clipped_polyline, gl_draw_text,
 	gl_set_draw_color, gl_set_draw_font, gl_set_line_style,
-    gl_set_line_width, gl_fill_circle, gl_draw_circle,
-    gl_get_background, gl_get_region,
-	gl_get_text_size, gl_fill_triangle };
+        gl_set_line_width, gl_fill_circle, gl_fill_ellipse,
+	gl_draw_circle, gl_draw_ellipse, gl_get_background,
+	gl_get_region, gl_get_text_size, gl_fill_triangle };
 
 Drawing_funcs *gl_drawing_funcs(void)
 {
@@ -1218,21 +1228,26 @@ void draw_clipped_line_gl_handler(Gl_handler gl_handler,
 #define  RADIANS_PER_PT  (DEGREES_PER_PT * RADIAN_SCALE)
 
 void fill_circle_gl_handler(Gl_handler gl_handler, float x, float y, float r)
+{
+    fill_ellipse_gl_handler(gl_handler, x, y, r, r);
+}
+
+void fill_ellipse_gl_handler(Gl_handler gl_handler, float x, float y, float rx, float ry)
 {
     int i;
     float x1, y1, x2, y2, angle;
 
 /*
-    printf("fill_circle_gl_handler: %2.1f %2.1f %2.1f\n", x, y, r);
+    printf("fill_ellipse_gl_handler: %2.1f %2.1f %2.1f %2.1f\n", x, y, rx, ry);
 */
-    x1 = x + r;
+    x1 = x + rx;
     y1 = y;
     glBegin(GL_TRIANGLES);
     for (i = 1; i <= NCIRCLE_PTS; i++)
     {
         angle = i * RADIANS_PER_PT;
-        x2 = x + r * (float) cos((double) angle);
-        y2 = y + r * (float) sin((double) angle);
+        x2 = x + rx * (float) cos((double) angle);
+        y2 = y + ry * (float) sin((double) angle);
         glVertex2f(x, y);
         glVertex2f(x1, y1);
         glVertex2f(x2, y2);
@@ -1244,21 +1259,26 @@ void fill_circle_gl_handler(Gl_handler gl_handler, float x, float y, float r)
 }
 
 void draw_circle_gl_handler(Gl_handler gl_handler, float x, float y, float r)
+{
+    draw_ellipse_gl_handler(gl_handler, x, y, r, r);
+}
+
+void draw_ellipse_gl_handler(Gl_handler gl_handler, float x, float y, float rx, float ry)
 {
     int i;
     float x1, y1, x2, y2, angle;
 
 /*
-    printf("draw_circle_gl_handler: %2.1f %2.1f %2.1f\n", x, y, r);
+    printf("draw_ellipse_gl_handler: %2.1f %2.1f %2.1f\n", x, y, r);
 */
-    x1 = x + r;
+    x1 = x + rx;
     y1 = y;
     glBegin(GL_LINE_LOOP);
     for (i = 1; i < NCIRCLE_PTS; i++)
     {
         angle = i * RADIANS_PER_PT;
-        x2 = x + r * (float) cos((double) angle);
-        y2 = y + r * (float) sin((double) angle);
+        x2 = x + rx * (float) cos((double) angle);
+        y2 = y + ry * (float) sin((double) angle);
         glVertex2f(x1, y1);
         glVertex2f(x2, y2);
         x1 = x2;
