@@ -170,11 +170,21 @@ static void tk_fill_circle(Generic_ptr data, float x, float y, float r)
     fill_circle_tk_handler((Tk_handler) data, x, y, r);
 }
 
+static void tk_fill_ellipse(Generic_ptr data, float x, float y, float rx, float ry)
+{
+    fill_ellipse_tk_handler((Tk_handler) data, x, y, rx, ry);
+}
+
 static void tk_draw_circle(Generic_ptr data, float x, float y, float r)
 {
     draw_circle_tk_handler((Tk_handler) data, x, y, r);
 }
 
+static void tk_draw_ellipse(Generic_ptr data, float x, float y, float rx, float ry)
+{
+    draw_ellipse_tk_handler((Tk_handler) data, x, y, rx, ry);
+}
+
 static void tk_get_background(Generic_ptr data, float *color)
 {
     Tk_handler_p tk_handler_p = (Tk_handler_p) data;
@@ -204,9 +214,9 @@ static Drawing_funcs drawing_funcs = { SCREEN_DRAWING,
 	tk_draw_line, tk_draw_clipped_line,
 	tk_draw_polyline, tk_draw_clipped_polyline, tk_draw_text,
 	tk_set_draw_color, tk_set_draw_font, tk_set_line_style,
-        tk_set_line_width, tk_fill_circle, tk_draw_circle,
-        tk_get_background, tk_get_region,
-	tk_get_text_size, tk_fill_triangle };
+        tk_set_line_width, tk_fill_circle, tk_fill_ellipse,
+	tk_draw_circle, tk_draw_ellipse, tk_get_background,
+	tk_get_region, tk_get_text_size, tk_fill_triangle };
 
 Drawing_funcs *tk_drawing_funcs()
 {
@@ -697,28 +707,38 @@ void draw_clipped_line_tk_handler(Tk_handler tk_handler,
 
 void fill_circle_tk_handler(Tk_handler tk_handler, float x, float y, float r)
 {
-    Tk_handler_p tk_handler_p = (Tk_handler_p) tk_handler;
-    int xx = CONVERT_X(x);
-    int yy = CONVERT_Y(y);
-    int rx = SCALE_X(r);
-    int ry = SCALE_Y(r);
-
-/*
-    printf("fill_circle_tk_handler1: %2.1f %2.1f %2.1f\n", x, y, r);
-    printf("fill_circle_tk_handler2: %d %d %d %d\n", xx, yy, rx, ry);
-*/
-
-    XFillArc(tk_handler_p->display, tk_handler_p->drawable,
-                tk_handler_p->gc, xx-rx, yy-ry, 2*rx, 2*ry, 64*0, 64*360);
+    fill_ellipse_tk_handler(tk_handler, x, y, r, r);
 }
 
-void draw_circle_tk_handler(Tk_handler tk_handler, float x, float y, float r)
+void fill_ellipse_tk_handler(Tk_handler tk_handler, float x, float y, float rx, float ry)
 {
     Tk_handler_p tk_handler_p = (Tk_handler_p) tk_handler;
     int xx = CONVERT_X(x);
     int yy = CONVERT_Y(y);
-    int rx = SCALE_X(r);
-    int ry = SCALE_Y(r);
+    int rxx = SCALE_X(rx);
+    int ryy = SCALE_Y(ry);
+
+/*
+    printf("draw_circle_tk_handler1: %2.1f %2.1f %2.1f\n", x, y, r);
+    printf("draw_circle_tk_handler2: %d %d %d %d\n", xx, yy, rx, ry);
+*/
+
+    XFillArc(tk_handler_p->display, tk_handler_p->drawable,
+                tk_handler_p->gc, xx-rx, yy-ry, 2*rxx, 2*ryy, 64*0, 64*360);
+}
+
+void draw_circle_tk_handler(Tk_handler tk_handler, float x, float y, float r)
+{
+    draw_ellipse_tk_handler(tk_handler, x, y, r, r);
+}
+
+void draw_ellipse_tk_handler(Tk_handler tk_handler, float x, float y, float rx, float ry)
+{
+    Tk_handler_p tk_handler_p = (Tk_handler_p) tk_handler;
+    int xx = CONVERT_X(x);
+    int yy = CONVERT_Y(y);
+    int rxx = SCALE_X(rx);
+    int ryy = SCALE_Y(ry);
 
 /*
     printf("draw_circle_tk_handler1: %2.1f %2.1f %2.1f\n", x, y, r);
@@ -726,7 +746,7 @@ void draw_circle_tk_handler(Tk_handler tk_handler, float x, float y, float r)
 */
 
     XDrawArc(tk_handler_p->display, tk_handler_p->drawable,
-                tk_handler_p->gc, xx-rx, yy-ry, 2*rx, 2*ry, 64*0, 64*360);
+                tk_handler_p->gc, xx-rx, yy-ry, 2*rxx, 2*ryy, 64*0, 64*360);
 }
 
 void draw_polyline_tk_handler(Tk_handler tk_handler, Poly_line polyline)
