@@ -77,9 +77,11 @@ from memops.editor.Util             import createDismissHelpButtonList
 
 from ccpnmr.analysis.popups.BasePopup       import BasePopup
 from ccpnmr.analysis.core.AssignmentBasic   import getAtomSetShifts, assignAtomsToRes, getShiftLists
-from ccpnmr.analysis.core.MoleculeBasic     import getResidueMapping, getLinkedResidue
+from ccpnmr.analysis.core.MoleculeBasic     import getResidueMapping
 from ccpnmr.analysis.core.ConstraintBasic   import getFixedResonance
-from ccpnmr.analysis.core.StructureBasic    import getResiduePhiPsi
+from ccp.lib.StructureLib                   import getResiduePhiPsi
+
+from ccp.lib.MoleculeQuery     import getLinkedResidue
 
 
 #
