@@ -92,7 +92,7 @@ def copyAttributeInfo(fromInstance,toInstance,overWrite = 1,verbose = True):
     # Get value...
     fromInstanceAttrValue = getattr(fromInstance,attrName)
    
-    if fromInstanceAttrValue == None or fromInstanceAttrValue == ():
+    if not fromInstanceAttrValue:
       # Ignore empty values
       continue
 
