@@ -62,6 +62,7 @@ software development. Bioinformatics 21, 1678-1684.
 import os, urllib, re
 
 from memops.universal import Io as uniIo
+from memops.universal import Util as uniUtil
 from memops.general.Implementation import ApiError
 from memops.general.Io import findCcpXmlFile, getCcpFileString
 from memops.api import Implementation
@@ -658,8 +659,10 @@ def findDataStoringFromFilepath(project, fullFilePath, preferDataUrls=None,
     # get filePath
     if ss == '/':
       ss = ''
+    elif uniUtil.isWindowsOS() and ss.endswith('/') and ss[-2] == ':': # deals with case on Windows when one has drive + '/'
+      ss = ss[:-1]
     else:
-      ss = uniIo.joinPath(dataUrl.url.path, '') # removes file separator from end, but not if just '/'
+      ss = uniIo.joinPath(dataUrl.url.path, '') # removes file separator from end, but not if just '/', hence special cases above
     filePath = fullFilePath[len(ss)+1:]
   
   else:
