@@ -105,60 +105,29 @@ def setCurrentStore(project, className, linkName = None, createNew = True):
 
   return currentStore
 
-def findAllSysNamesByChemAtoms(chemComp,chemAtomList,namingSystemName):
+def findAllSysNamesByChemAtomOrSet(chemComp, chemAtomOrSetList, namingSystemName):
 
   #
-  # Returns all sysNames for a chemComp based on a list of chemAtoms.
+  # Returns all sysNames for a chemComp based on a list of chemAtoms or chemAromSets.
   # Returns None if no direct matches to the namingSystem
   #
 
-  namingSystem = chemComp.findFirstNamingSystem(name = namingSystemName)
+  namingSystem = chemComp.findFirstNamingSystem(name=namingSystemName)
   chemAtomSysNames = []
 
   if namingSystem:
-    for chemAtom in chemAtomList:
-      casn = findAtomSysNameByChemAtom(namingSystem,chemAtom)
+    for chemAtom in chemAtomOrSetList:
+      casn = findChemAtomOrSetSysName(namingSystem, chemAtom)
 
       if casn:
         chemAtomSysNames.append(casn)
 
   return chemAtomSysNames
 
-def findAllSysNamesByChemAtomSets(chemComp,chemAtomSetList,namingSystemName):
-
-  #
-  # Returns all sysNames for a chemComp based on a list of chemAtomSets.
-  # Returns None if no direct matches to the namingSystem
-  #
-
-  namingSystem = chemComp.findFirstNamingSystem(name = namingSystemName)
-  chemAtomSetSysNames = []
-
-  if namingSystem:
-    for chemAtomSet in chemAtomSetList:
-      casn = findAtomSysNameByChemAtomSet(namingSystem,chemAtomSet)
-
-      if casn:
-        chemAtomSetSysNames.append(casn)
-
-  return chemAtomSetSysNames
-
-def findAtomSysNameByChemAtom(namingSystem,chemAtom):
-
-  searchDict = {'atomName': chemAtom.name, 'atomSubType': chemAtom.subType}
-
-  return findChemAtomSysName(namingSystem,searchDict)
-
 def findChemAtomSysName(namingSystem,searchDict):
 
   return findAtomSysName(namingSystem,searchDict,'atomReference')
 
-def findAtomSysNameByChemAtomSet(namingSystem,chemAtomSet):
-
-  searchDict = {'atomName': chemAtomSet.name, 'atomSubType': chemAtomSet.subType}
-
-  return findChemAtomSetSysName(namingSystem,searchDict)
-
 def findChemAtomSetSysName(namingSystem,searchDict):
 
   return findAtomSysName(namingSystem,searchDict,'atomSetReference')
@@ -183,6 +152,49 @@ def findAtomSysName(namingSystem,searchDict,refType):
 
   return casn
 
+
+def findChemAtomOrSetSysName(namingSystem, chemAtomOrSet, warnAtomId=None,
+                             findIupac=False):
+  """Input: ChemComp. ChemAtom or ChemAtomSet
+            ChemComp.NamingSystem
+            Boolean findIUPAC. Check IUPAC if nothing found in namingSystem?
+     Output: ChemComp.AtomSysName matching chemAtomOrSet
+  """
+  
+  # initialise
+  result = None
+  
+  # set link name for finding next naming system depending on input type
+  if chemAtomOrSet.className == 'ChemAtomSet':
+    nextSysTag = 'atomSetReference'
+  else:
+    nextSysTag = 'atomReference'
+  
+  # Look through successive namingSystems for a match
+  name = chemAtomOrSet.name
+  subType = chemAtomOrSet.subType
+  ns = namingSystem
+  while bool(ns and not result):
+  
+    result = ns.findFirstAtomSysName(atomName=name, atomSubType=subType)
+    ns = getattr(ns, nextSysTag)
+  
+  if findIupac and (not result or result.sysName == voidAtomSysName):
+    # Now try IUPAC instead
+    
+    if warnAtomId:
+      print ("  Warning: no %s atomSysName available for '%s', trying IUPAC." 
+             % (namingSystem.name, warnAtomId))
+
+    ns = chemAtomOrSet.chemComp.findFirstNamingSystem(name='IUPAC')
+    if ns:
+      result = ns.findFirstAtomSysName(atomName=name, atomSubType=subType)
+  
+  if result and result.sysName == voidAtomSysName:
+    result = None
+  #
+  return result
+  
 def findChemCompSysName(namingSystemName,chemComp):
 
   sysName = None
@@ -1184,7 +1196,7 @@ class MakeAtomSets:
                     chemAtomProtons[chemAtom].append(otherAtom)
 
                 # If any has no protons, just ignore this list...
-                if chemAtomProtons[chemAtom] == []:
+                if not chemAtomProtons[chemAtom]:
                   noProtons = 1
 
               # If any has no protons, just ignore this chemAtomCentral...
@@ -2058,3 +2070,133 @@ def parseBrukerSummary(fileName, **kw):
   #
   return result
 
+
+
+def getAmbigNamingPriority(resonance, chemAtomSet=None):
+  """Determine if an ambigous prochiral Resonance or FixedResonance 
+  (non-stereospecifically assigned) should be assigned to the first
+  (return 0) or the second name (return 1) alphabetically
+  
+  ChemAtomSet must match the assignment of the Resonance. If not passed in it is
+  generated from the atomSets
+  
+  The function gives reproducible results for the same assignment state,
+  regardless of shift values.
+  Results for proton and carbon of CH(CH3)2 groups are consistent.
+  If Resonance.name are set according to Analysis shift value convention, the
+  resultant priorities are reproduced.
+  If resonance.name matches a ChemAtomOrSet exactly, this will be matched
+  
+  .. describe:: Input
+  
+  Nmr.Resonance or NmrConstraint.FixedResonance
+  ChemComp.ChemAtomSet (optional)  
+  
+  .. describe:: Output
+  
+  0/1/None Index of preferred name in alphabetical list of alternative names,
+  """
+  
+  # set up
+  priority = None
+  resonanceSet = resonance.resonanceSet
+  resonanceName = resonance.name
+  if resonanceSet:
+  
+    # get otherResonance
+    ll = [x for x in resonanceSet.resonances if x is not resonance]
+    if ll:
+      otherResonance = ll[0]
+    else:
+      otherResonance = None
+    
+    if resonance.isotopeCode != '1H':
+      # heavy atom resonance. 
+      # First try using bound protons(needed e.g. for CH(CH3)2 groups)
+      resonance2 = resonance.findFirstCovalentlyBound(isotopeCode='1H')
+      if resonance2 is not None:
+        # get priority of bound proton
+        priority = getAmbigNamingPriority(resonance2)
+      
+      if priority is None and otherResonance is not None:
+        resonance3 = otherResonance.findFirstCovalentlyBound(isotopeCode='1H')
+        if resonance3 is not None:
+          # get priority from bound proton of partner
+          priority = getAmbigNamingPriority(resonance3)
+          if priority is not None:
+            priority = 1-priority
+    
+    if priority is None:
+      # now use the resonance itself
+      
+      if otherResonance is None:
+        if chemAtomSet is None:
+          chemAtomSet = getChemAtomSetFromAtomSets(resonanceSet.atomSets)
+        if chemAtomSet is not None:
+          ll = chemAtomSet.sortedChemAtomSets() or chemAtomSet.sortedChemAtoms()
+          names = [x.name for x in ll]
+          if resonanceName in names:
+            # Priority from exact match to ChemAtomOrSet.name
+            priority = names.index(resonanceName)
+        
+        if priority is None:
+          if resonanceName and (resonanceName.endswith('b') 
+                                or resonanceName.endswith('b*')):
+            # Get priority from Analysis-type assignment names
+            priority = 1
+          else:
+            # Only resonance available, and nothing to work with. Use first name
+            priority = 0
+            
+      
+      else:
+        # We have two resonances
+        # sort on name, then serial to get priority
+        if ( (resonanceName, resonance.serial) < 
+            (otherResonance.name, otherResonance.serial)):
+          priority = 0
+        else:
+          priority = 1
+  
+  #
+  return priority
+
+
+def getChemAtomSetFromAtomSets(atomSets):
+  """ Get a ChemAtomSet that matches all atoms in atomSets
+  
+  .. describe:: Input
+  
+  List of Nmr.AtomSet or NmrConstraint.FixedAtomSet
+  
+  .. describe:: Output
+  
+  ChemComp.ChemAtomSet (or None)
+  
+  """
+  
+  atoms = []
+  for atomSet in atomSets:
+    atoms.extend(atomSet.atoms)
+  
+  chemAtoms = [x.chemAtom for x in atoms]
+  if None in chemAtoms:
+    return None
+  
+  chemAtomSets = set(x.chemAtomSet for x in chemAtoms)
+  if None in chemAtomSets:
+    return None
+  
+  nChemAtoms = 0
+  for chemAtomSet in chemAtomSets:
+    nChemAtoms += len(chemAtomSet.chemAtoms)
+  if nChemAtoms != len(atoms):
+    return None
+    
+  
+  while len(chemAtomSets) > 1:
+    chemAtomSets = set(x.chemAtomSet for x in chemAtomSets)
+    if None in chemAtomSets:
+      return None
+  else:
+    return chemAtomSets.pop()
