@@ -64,6 +64,7 @@ try:
 except:
   from memops.universal.MessageReporter import showWarning
 
+from memops.general.Util import copySubTree
 from ccp.general.Io import getChemComp
 
 #################################################################
@@ -263,7 +264,7 @@ def makeLinearSequence(molecule, sequence, seqCodeStart=1, isCyclic=False):
       prevLinkEnd = molResidues[0].findFirstMolResLinkEnd(linkCode='prev')
       molResLinkEnds.append(prevLinkEnd)
       molResLinks.append(
-       molecule.MolResLink(molResLinkEnds=[nextLinkEnd,prevLinkEnd])
+       molecule.newMolResLink(molResLinkEnds=[nextLinkEnd,prevLinkEnd])
       )
     
     # final validity check
