@@ -38,7 +38,7 @@ Development of a Software Pipeline. Proteins 59, 687 - 696.
 ===========================REFERENCE END===============================
 
 """
-from os import path
+import os
 
 from ccp.lib import DataConvertLib
 from ccp.lib.MoleculeAlign import findMatchingChains
@@ -73,6 +73,8 @@ def getStructureFromFile(molSystem, filePath, fileType='rough', doWarnings=True)
   MolStructure.StructureEmsemble
   """
   
+  coordDict = {}
+  
   if fileType == 'true':  
     coordDict = _makeStructureDictFromPdb(filePath, fileType='pdb')
   elif fileType == 'cns':
@@ -83,6 +85,8 @@ def getStructureFromFile(molSystem, filePath, fileType='rough', doWarnings=True)
     try:
       coordDict = _makeStructureDictFromPdb(filePath, fileType='pdb')
     except:
+      pass
+  if not coordDict:
       coordDict = _makeStructureDictFromRoughPdb(filePath)
 
   ensemble = None
@@ -92,7 +96,7 @@ def getStructureFromFile(molSystem, filePath, fileType='rough', doWarnings=True)
 
     if ensemble:
       models = ensemble.sortedModels()
-      fileRoot, fileExt = path.splitext(path.split(filePath)[1])
+      fileRoot, fileExt = os.path.splitext(os.path.split(filePath)[1])
     
       if len(models) > 1:
         for model in models:
@@ -117,7 +121,7 @@ def getStructureFromFiles(molSystem, pdbPaths, fileType=None, doWarnings=True):
     print ('WARNING no files to read. Skipping')
   
   elif len(pdbPaths) == 1:
-    return getStructureFromFile(molSystem, filePath, fileType, doWarnings)
+    return getStructureFromFile(molSystem, pdbPaths[0], fileType, doWarnings)
   
   else:
   
