@@ -45,7 +45,7 @@ from memops.general import Implementation
 
 from memops.general.Application import Application
 from memops.general.Io import backupProject
-from memops.general import Version
+# from memops.general import Version
 
 from memops.universal.Io import joinPath
 from memops.universal.Util import isWindowsOS
@@ -61,7 +61,7 @@ from ccp.api.nmr import Nmr
 from ccp.general.Io import getDataSourceFileName
 from ccp.util.ShapeUtil import create1dShape
 
-from ccpnmr.api.AnalysisProfile import Macro
+# from ccpnmr.api.AnalysisProfile import Macro
 
 from ccpnmr.analysis.Citation import analysisReference
 from ccpnmr.analysis.macros.ArgumentServer import ArgumentServer
@@ -301,6 +301,10 @@ class Analysis:
     notify(self.initPeakList, 'ccp.nmr.Nmr.PeakList', '__init__')
 
     self.initSpectra()
+
+    # Re-average shifts - done centrally instead of doing it in initPeakLists
+    for shiftList in set(x.shiftList for x in project.currentNmrProject.experiments):
+      AssignmentBasic.updateAllShifts(shiftList)
     
     if not Util.isTopObjectAnalysisInitialised(project.currentNmrProject):
       self.initResonances()
@@ -1950,7 +1954,8 @@ class Analysis:
         #if not peak.annotation:
         #  PeakBasic.makePeakAnnotation(peak)
 
-        if peak.figOfMerit == 0.0:
+        if peak.figOfMerit == 0.0 and not initialising:
+          # If initialising we average shifts elsewhere. Do not know why the figOfMerit
           AssignmentBasic.updatePeakShifts(peak)
 
         for peakDim in peak.peakDims:
@@ -2451,7 +2456,7 @@ class Analysis:
     
       resDict[molType][resProfile.ccpCode] = resProfile.guiName
      
-    MoleculeBasic.userResidueCodesDict = resDict
+    MoleculeBasic.setUserResidueCodesDict(resDict)
 
   def cacheResidueCode(self, residueProfile):
    
