@@ -343,7 +343,7 @@ def assignPeakDimComponentResonance(component, resonance, tolerance=None):
   return peakDimContrib
     
 
-def getCouplingTolerance(conponent, dataDimRef):
+def getCouplingTolerance(component, dataDimRef):
   """
   Get the coupling assignment tolerance (usually Hz)
   for a given data dim.
@@ -364,7 +364,7 @@ def getCouplingTolerance(conponent, dataDimRef):
   if unit != 'point':
     delta /= dataDimRef.valuePerPoint
   
-  tolerance = conponent.dataDimRef.pointToValue(delta)
+  tolerance = component.dataDimRef.pointToValue(delta)
 
   return tolerance
 
