@@ -49,7 +49,10 @@ from ccpnmr.analysis.core.Util import getAnalysisDataDim
 
 from memops.general.Implementation import ApiError
 
-from memops.gui.MessageReporter import showWarning
+try:
+  from memops.gui.MessageReporter import showWarning
+except ImportError:
+  from memops.universal.MessageReporter import showWarning
 
 from ccp.general.Constants import chemShiftRefRatios
 
