@@ -126,12 +126,20 @@ DNARNA_MOLTYPE = 'DNA/RNA'
 #
 
 
+"""
 userResidueCodesDict = {DNA_MOLTYPE:{'A':'Ade','T':'Thy','G':'Gua','C':'Cyt','U':'Ura'},
                         RNA_MOLTYPE:{'A':'Ade','T':'Thy','G':'Gua','C':'Cyt','U':'Ura','I':'Ino'},
                         PROTEIN_MOLTYPE:{},
                         CARBOHYDRATE_MOLTYPE:{}
                         }
+"""
+userResidueCodesDict = MoleculeQuery.userResidueCodesDict
 
+def setUserResidueCodesDict(resDict):
+
+  global userResidueCodesDict
+  MoleculeQuery.userResidueCodesDict = resDict
+  userResidueCodesDict = resDict
       
 # NOT Currently Used.
 def getLinkAtoms(residueA, linkCode='prev'):
