@@ -719,7 +719,8 @@ def updateShiftSatsList(array, minPpm, meanPpm, maxPpm):
 
     array[1] += 1
 
-def analyseAssignmentCompleteness(molSystem, shiftList, residueSelection=None):
+def analyseAssignmentCompleteness(molSystem, shiftList, residueSelection=None,
+                                  excludeWaterExchangeable=True):
 
   from ccpnmr.analysis.core.MoleculeBasic import greekSortAtomNames
   # ['Category','Available','Assigned','% Assigned']
@@ -759,7 +760,7 @@ def analyseAssignmentCompleteness(molSystem, shiftList, residueSelection=None):
       
       for atom in residue.atoms:
         
-        if atom.chemAtom.waterExchangeable:
+        if atom.chemAtom.waterExchangeable and excludeWaterExchangeable:
           continue
         
         atomSet = atom.atomSet
@@ -812,9 +813,10 @@ def analyseAssignmentCompleteness(molSystem, shiftList, residueSelection=None):
               atomTypes[atomType][0] += 1
               
               if molType == 'protein':
-                if atom.name in ('H','N','C','CA'):
+                # wb104: 4 Aug 2014: added HA,HA2,HA3 to the backbone
+                if atom.name in ('H','N','C','CA','HA','HA2','HA3'):
                   
-                  if atom.name != 'H':
+                  if element != 'H':
                     backboneX[0] +=1
                     if isAssigned:
                       backboneX[1] += 1
@@ -884,9 +886,9 @@ def analyseAssignmentCompleteness(molSystem, shiftList, residueSelection=None):
       meanPpm /= float(found)
     data.append(['Element ' + e, maxNum, found, 100.0*found/N, minPpm, meanPpm, maxPpm])
   
-  classes = [('Amide',amide),
-             ('Backbone',backbone),
-             ('Backbone non-H',backboneX),
+  classes = [('(Backbone)N+H',amide),
+             ('Backbone+H+HA',backbone),
+             ('Backbone',backboneX),
              ('Side Chain H',sideH),
              ('Side Chain non-H',sideX),
              ('Ribose H',riboseH),
