@@ -54,7 +54,7 @@ from memops.general import Version
 
 try:
   from memops.gui.MessageReporter import showError
-except:
+except ImportError:
   from memops.universal.MessageReporter import showError
 
 from memops.api import Implementation
@@ -935,8 +935,10 @@ def setPeakTextOffset(peak, textOffset):
   return textOffset
 
 
-def isTopObjectAnalysisInitialised(topObject, tolerance=10):
-  # Tolerance is max difference between app data save time and file mod time
+def isTopObjectAnalysisInitialised(topObject, tolerance=50):
+  """tolerance is max difference between app data save time and file mod time (in seconds)
+     RHF 5 June 2014. Increased tolerance from 10 to 50s, as discrepancy can be at least 28s
+  """
 
   repository = topObject.findFirstActiveRepository()
   if not repository:
