@@ -46,7 +46,10 @@ from ccpnmr.analysis.core import ExperimentBasic
 from ccpnmr.analysis.core.PeakBasic import getPeakDimPosition, uniteResonancePeakPositions
 from ccpnmr.analysis.core import Util
 
-from memops.gui.MessageReporter import showWarning
+try:
+  from memops.gui.MessageReporter import showWarning
+except ImportError:
+  from memops.universal.MessageReporter import showWarning
 
 from memops.universal.Region1D import Region1D
 
@@ -2821,42 +2824,50 @@ def getSpinSystemWindowShifts(spinSystems, windowPane, shiftList=None):
   xShifts = []
   yShifts = []
   zListShifts = [ [] for axisPanel in sortedAxisPanels[2:] ]
-  
+
   for j, spinSystem in enumerate(spinSystems):
     resonanceDict = {}
-    
+
     for resonance in spinSystem.resonances:
       resonanceDict[resonance] = True
-      
+
       for resonance2 in getBoundResonances(resonance):
         resonanceDict[resonance2] = True
-  
+
     for resonance in resonanceDict.keys():
       shift = resonance.findFirstShift(parentList=shiftList)
       if shift:
         if resonance.isotopeCode in xIsotopes:
           if (shift.value >= ranges[0][0]) and (shift.value <= ranges[0][1]):
-            sortShifts.append( (j, shift) )
+            if stripAxis == 'x':
+              sortShifts.append( (j, shift) )
             xShifts.append( shift )
 
         if resonance.isotopeCode in yIsotopes:
           if (shift.value >= ranges[1][0]) and (shift.value <= ranges[1][1]):
+            if stripAxis == 'y':
+              sortShifts.append( (j, shift) )
             yShifts.append( shift )
- 
+
         for i, zIsotopes in enumerate(zIsotopeList):
-          # Could have a 2D mapped to a 3D window 
+          # Could have a 2D mapped to a 3D window
           if i+2 >= len(ranges):
-            break 
-          
+            break
+
           if resonance.isotopeCode in zIsotopes:
             if (shift.value >= ranges[i+2][0]) \
                and (shift.value <= ranges[i+2][1]):
               zListShifts[i].append( shift )
 
-  shifts    = []    
+  if stripAxis == 'x':
+    orthoShifts = yShifts
+  else:
+    orthoShifts = xShifts
+
+  shifts    = []
   for j, shift in sortShifts:
     shiftDict = {stripAxis:shift}
-    
+
     foundZ = False
     for i, zShifts in enumerate(zListShifts):
       for zShift in zShifts:
@@ -2864,24 +2875,32 @@ def getSpinSystemWindowShifts(spinSystems, windowPane, shiftList=None):
           shiftDict['z%d' % (i+1,)] = zShift
           foundZ = True
           break
-    
+
+    if not foundZ:
+      for orthoShift in orthoShifts:
+        # Maybe:
+        #if not areResonancesBound(orthoShift.resonance,shift.resonance):
+        #  continue
+
+        for i, zShifts in enumerate(zListShifts):
+          for zShift in zShifts:
+            if areResonancesBound(orthoShift.resonance,zShift.resonance):
+              shiftDict['z%d' % (i+1,)] = zShift
+              foundZ = True
+              break
+
     if zIsotopeList and not foundZ:
       continue
-      
+
     shifts.append((j,shift.value, shiftDict))
 
   shifts.sort()
   shifts.reverse()
   shifts = [x[2] for x in shifts]
 
-  if stripAxis == 'x':
-    orthoShifts = yShifts
-  else:
-    orthoShifts = xShifts
-
   return shifts, orthoShifts
 
-def gotoResonancePosition(analysis, resonance, windowPane, shiftList):
+def gotoResonancePosition(analysis, resonance, windowPane, shiftList, row=None, col=None):
   """
   Go to the position of a given resonance (according to the input
   shiftlist) in a given window. Note currently only goes to first
@@ -2899,7 +2918,7 @@ def gotoResonancePosition(analysis, resonance, windowPane, shiftList):
 
   shift = resonance.findFirstShift(parentList=shiftList)
 
-  if shift:    
+  if shift:
     axisPanels = []
     for axisPanel in windowPane.axisPanels:
       if axisPanel.axisType:
@@ -2926,10 +2945,10 @@ def gotoResonancePosition(analysis, resonance, windowPane, shiftList):
     position = {}
     for axis in axisLabels:
       position[axis] = shift.value
- 
+
     if hasattr(windowPane, 'getWindowFrame'):
       windowFrame = windowPane.getWindowFrame()
-      windowFrame.gotoPosition(position)
+      windowFrame.gotoPosition(position, row=row, col=col)
 
 def displaySpinSystemStrips(analysis, spinSystems, windowPane,
                             shiftList=None, splitIntoCells=False):
@@ -3053,3 +3072,32 @@ def setTiedAxisPanels(axisPanel, tiedAxisPanels):
   application = project.application
   application.setValues(axisPanel, TIED_AXIS, values)
 
+VALUE_AXIS_OFFSET = 'valueAxisOffset'
+
+def getValueAxisOffset(view):
+  
+  application = view.root.application
+  
+  return application.getValue(view, keyword=VALUE_AXIS_OFFSET) or 0.0
+  
+def setValueAxisOffset(view, value):
+  
+  application = view.root.application
+ 
+  application.setValue(view, keyword=VALUE_AXIS_OFFSET, value=value)
+  
+X_AXIS_OFFSET = 'xAxisOffset'
+
+def getXAxisOffset(view):
+  
+  application = view.root.application
+  
+  return application.getValue(view, keyword=X_AXIS_OFFSET) or 0.0
+  
+def setXAxisOffset(view, value):
+  
+  application = view.root.application
+ 
+  application.setValue(view, keyword=X_AXIS_OFFSET, value=value)
+
+  
