@@ -59,9 +59,12 @@ from ccpnmr.analysis.core.Util import checkSwapRegion, calcPointsPerPixel, \
                                       getDimWrapped, isIsotopeAxisType
 
 from ccpnmr.analysis.core.WindowBasic import windowPaneHasValueAxis, getSpectrumWindowView
-from ccpnmr.analysis.core.WindowBasic import getAxisRegionRegion
+from ccpnmr.analysis.core.WindowBasic import getAxisRegionRegion, getXAxisOffset, getValueAxisOffset
 
-from memops.gui.Color import hexToRgb, inverseGrey, inverseRgb
+try:
+  from memops.gui.Color import hexToRgb, inverseGrey, inverseRgb
+except ImportError:
+  pass # code below might fail, but not much can do, above functions should not be in gui
 
 try:
   import ccpnmr.c.ContourStyle as ContourStyle
@@ -278,7 +281,7 @@ class WindowDraw:
         d = 0.5 * (r1 - r0)
         region = (p-d, p+d)
 
-        #print 'mid1 gotoXStripPosition', col, label
+        # print 'mid1 gotoXStripPosition', col, label, position
         if label in ('x', 'y'):
           axisRegion.region = region
           # above automatically updates scrollbar
@@ -288,7 +291,7 @@ class WindowDraw:
           # above directly updates scrollbar and indirectly sets axisRegion.region
           # should not be updating widgets in WindowDraw!
           axisRegion.region = region
-        #print 'mid2 gotoXStripPosition', col, label
+        # print 'mid2 gotoXStripPosition', col, label, position
 
     if doLift:
       self.lift()
@@ -716,9 +719,13 @@ class WindowDraw:
 
       #print 'determineDimRange1', axisPanel.label, dataDim.dim, view_region, world_region
 
+      if self.hasValueAxis and axisPanel.label == 'x':
+        offset = getXAxisOffset(view)
+        view_region = [view_region[0]-offset, view_region[1]-offset]
+
       view_region = convertRegion(view_region, axisPanel.axisUnit, dataDim)
       world_region = convertRegion(world_region, axisType.findFirstAxisUnit(unit='ppm'), dataDim)
-
+      
       #print 'determineDimRange2', axisPanel.label, gdataDim.dim, view_region, world_region
 
     axisMapping.view_region = view_region
@@ -810,8 +817,9 @@ class WindowDraw:
       (r0, r1) = (y0, y1) = (0.0, 1.0)
       (b0, b1) = getAxisRegionRegion(axisRegion)
       scale = spectrum.scale
-      b0 = b0 / scale
-      b1 = b1 / scale
+      offset = getValueAxisOffset(view)
+      b0 = b0 / scale - offset
+      b1 = b1 / scale - offset
     else:
       yaxisMapping = view.findFirstAxisMapping(label='y')
       ydim = yaxisMapping.analysisDataDim.dataDim.dim
