@@ -65,9 +65,10 @@ from ccpnmr.analysis.core.AssignmentBasic import assignResonanceType, getResonan
                                             makeResonanceGuiName, assignAtomsToRes, mergeResonances, \
                                             addSpinSystemResonance, removeSpinSystemResonance, assignResonanceResidue, \
                                             swapProchiralResonance, splitResonance, clearResonancePeakDimContribs, \
-                                            getShiftLists
+                                            getShiftLists, getResidueResonances, getOnebondResonances
 
-from ccpnmr.analysis.core.WindowBasic import getWindowPaneName, displayStrips, gotoResonancePosition
+from ccpnmr.analysis.core.WindowBasic import getWindowPaneName, displayStrips, gotoResonancePosition, \
+                                             windowPaneHasValueAxis
 from ccpnmr.analysis.core.MarkBasic import createRuler
 from ccpnmr.analysis.core.MoleculeBasic import getResidueCode
 from ccpnmr.analysis.core.CouplingBasic import getPeakDimComponentSplitting
@@ -180,6 +181,7 @@ class BrowseResonancesPopup(BasePopup):
     self.chain = None
     self.ccpCode = None
     self.rulers = []
+    self.residueRulers = []
     self.windowPane = None
     self.resonance = None
     self.shift = None
@@ -292,6 +294,41 @@ class BrowseResonancesPopup(BasePopup):
     self.clearMarksButton = Button(frame, text='Clear Marks', grid=(0,7,),
                                    command=self.clearMarks, bd=1, sticky='ew', tipText=tipText)
 
+    row += 1
+    frame = Frame(guiFrame, grid=(row,0))
+    frame.expandGrid(0,0)
+    tipText = 'Options to create strips for residue resonances in three spectrum windows'
+    div = LabelDivider(frame, text='Strip Residue Resonances',
+                       tipText=tipText, grid=(0,0))
+    
+    row += 1
+    frame = Frame(guiFrame, grid=(row,0))
+    frame.expandGrid(0,5)
+    
+    tipText = 'Selects the first spectrum window to use for residue resonances'    
+    label = Label(frame, text='>2D Window:', grid=(0,0))
+    self.windowRes1Pulldown = PulldownList(frame, grid=(0,1), tipText=tipText)
+    
+    tipText = 'Selects the second spectrum window to use for residue resonances, which should have y and z axes swapped relative to first window'    
+    label = Label(frame, text='>2D Window:', grid=(0,2))
+    self.windowRes2Pulldown = PulldownList(frame, grid=(0,3), tipText=tipText)
+    
+    tipText = 'Selects a 2D spectrum window to use for residue resonances'    
+    label = Label(frame, text='2D Window:', grid=(0,4))
+    self.windowRes3Pulldown = PulldownList(frame, grid=(0,5), tipText=tipText)
+    
+    tipText = 'Create strips at the residue resonance positions'    
+    self.stripResButton = Button(frame, text='Make Residue Strips', grid=(1,0), gridSpan=(1,2),
+                                command=self.stripResidueResonances, bd=1, sticky='ew', tipText=tipText)
+    
+    tipText = 'Put multi-dimensional cross marks at the residue resonance positions'    
+    self.markResButton = Button(frame, text='Mark Residue Resonances', grid=(1,2), gridSpan=(1,2),
+                                command=self.markResidueResonances, bd=1, sticky='ew', tipText=tipText)
+    
+    tipText = 'Remove the marks at the residue resonance positions'    
+    self.clearMarksButton = Button(frame, text='Clear Residue Marks', grid=(1,4,), gridSpan=(1,2),
+                                   command=self.clearResidueMarks, bd=1, sticky='w', tipText=tipText)
+    
     row += 1
     tipText = 'The main table displaying the resonance records in the selected shift list, and considering filtering options'
     div = LabelDivider(guiFrame, text='Resonance Table',
@@ -444,6 +481,46 @@ class BrowseResonancesPopup(BasePopup):
     self.windowPulldown.setup(names, windowPanes, index)
   
   
+  def getResWindows(self):
+
+    windowPanes2D = []
+    windowPanesND = []
+    for window in self.analysisProject.spectrumWindows:
+      for windowPane in window.spectrumWindowPanes:
+        if windowPaneHasValueAxis(windowPane):
+          continue
+        n = len(windowPane.axisPanels)
+        if n == 2:
+          windowPanes2D.append((getWindowPaneName(windowPane), windowPane))
+        elif n > 2:
+          windowPanesND.append((getWindowPaneName(windowPane), windowPane))
+
+    windowPanes2D.sort()
+    windowPanesND.sort()
+
+    return [x[1] for x in windowPanes2D], [x[1] for x in windowPanesND]
+
+  def updateResWindowsAfter(self, *windowPane):
+
+    self.after_idle(lambda :self.updateResWindows()) # Axis panel notifiers need a bit of time
+
+  def updateResWindows(self, *windowPane):
+
+    windowPanes2D, windowPanesND = self.getResWindows()
+
+    for windowPanes, windowPulldown in ((windowPanesND, self.windowRes1Pulldown),
+                                        (windowPanesND, self.windowRes2Pulldown),
+                                        (windowPanes2D, self.windowRes3Pulldown)):
+      names  = ['<None>'] + [getWindowPaneName(p) for p in windowPanes]
+      windowPanes = [None] + windowPanes
+
+      windowPane  = windowPulldown.getObject()
+      if windowPane not in windowPanes:
+        windowPane = None
+
+      index = windowPanes.index(windowPane)
+      windowPulldown.setup(names, windowPanes, index)
+
   def changeWindow(self, windowPane):
 
     if windowPane is not self.windowPane:
@@ -517,9 +594,17 @@ class BrowseResonancesPopup(BasePopup):
       if len(bound) == 1:
         gotoResonancePosition(self.guiParent, bound[0],
                               self.windowPane, shiftList)
-        
+
+  def gotoResonancesPosition(self, windowPane, resonances, **rowColDict):
+
+    if self.shift:
+      shiftList = self.shift.parentList
+      for resonance in resonances:
+        gotoResonancePosition(self.guiParent, resonance,
+                              windowPane, shiftList, **rowColDict)
+
   def markSelected(self):
-  
+
     if self.resonance and self.shift:
     
       shifts = [x[1] for x in self.scrolledMatrix.currentObjects if x[1]]
@@ -551,7 +636,94 @@ class BrowseResonancesPopup(BasePopup):
     for ruler in self.rulers:
       if not ruler.isDeleted:
         ruler.delete()
+        
+  def stripResidueResonances(self):
+    
+    if not self.resonance:
+      return
+
+    residue = getResonanceResidue(self.resonance)
+    if not residue:
+      return
+
+    resonancePairs = []
+    carbonResonances = getResidueResonances(residue, atomType='C')
+    for carbonResonance in carbonResonances:
+      (molSystem, chain, residue, name) = getResonanceAtomTuple(carbonResonance)
+      protonResonances = getOnebondResonances(carbonResonance, isotopeCode='1H')
+      for protonResonance in protonResonances:
+        # wb104: not sure why we need to do the below but Igor's macro did it
+        (molSystem1, chain1, residue1, name1) = getResonanceAtomTuple(protonResonance)
+        if name=='Cga' or name=='Cgb' or name=='Cda' or name=='Cdb':
+          if name[1:3]!=name1[1:3]:
+            continue
+        resonancePairs.append([carbonResonance,protonResonance])
+      
+    for windowPulldown in (self.windowRes1Pulldown, self.windowRes2Pulldown, self.windowRes3Pulldown):
+      windowPane = windowPulldown.getObject()
+      if windowPane:
+        windowFrame = windowPane.getWindowFrame()
+        numStrips = len(resonancePairs)
+        if windowPane.spectrumWindow.stripAxis == 'x':
+          windowFrame.setColsTo(numStrips)
+          attr = 'col'
+        else:
+          windowFrame.setRowsTo(numStrips)
+          attr = 'row'
+        for strip, resonancePair in enumerate(resonancePairs):
+          rowColDict = {attr: strip}
+          self.gotoResonancesPosition(windowPane, resonancePair, **rowColDict)
   
+  def markResidueResonances(self):
+
+    if not self.resonance:
+      return
+
+    residue = getResonanceResidue(self.resonance)
+    if not residue:
+      return
+
+    carbonResonances = getResidueResonances(residue, atomType='C')
+    for carbonResonance in carbonResonances:
+      self.markResonance(carbonResonance)
+      protonResonances = getOnebondResonances(carbonResonance, isotopeCode='1H')
+      for protonResonance in protonResonances:
+        self.markResonance(protonResonance)
+  
+  def clearResidueMarks(self):
+
+    for ruler in self.residueRulers:
+      if not ruler.isDeleted:
+        ruler.delete()
+  
+  def markResonance(self, resonance):
+
+    if not self.shiftList:
+      return
+
+    shift= resonance.findFirstShift(parentList=self.shiftList)
+    if not shift:
+      return
+
+    for windowPulldown in (self.windowRes1Pulldown, self.windowRes2Pulldown, self.windowRes3Pulldown):
+      windowPane = windowPulldown.getObject()
+      if not windowPane:
+        continue
+      panelTypes = [ap.panelType for ap in self.windowPane.axisPanels if ap.panelType]
+      panelTypeDict = {}
+
+      for panelType in panelTypes:
+        for isotope in panelType.axisType.isotopeCodes:
+          if panelTypeDict.get(isotope) is None:
+            panelTypeDict[isotope] = []
+        panelTypeDict[isotope].append(panelType)
+
+      panelTypes = panelTypeDict.get(shift.resonance.isotopeCode, [])
+
+      for panelType in panelTypes:
+        ruler = createRuler(shift.value, panelType, remove=False)
+        self.residueRulers.append(ruler)
+
   def updateButtons(self):
   
     self.stripButton.disable()
@@ -778,6 +950,7 @@ class BrowseResonancesPopup(BasePopup):
     self.resonance = resonance
     self.shift = shift
     self.updateButtons()
+    self.updateResWindows()
             
   def getShiftListNames(self, shiftLists):
     
@@ -1183,7 +1356,8 @@ class BrowseResonancesPopup(BasePopup):
 
     for func in ('__init__', 'delete','setName'):
       notifyFunc(self.updateWindowsAfter, 'ccpnmr.Analysis.SpectrumWindow', func)
-   
+      notifyFunc(self.updateResWindowsAfter, 'ccpnmr.Analysis.SpectrumWindow', func)
+
     #notifyFunc(self.updateAfter, 'ccp.nmr.Nmr.Shift', 'getResonance')
  
   def destroy(self):
@@ -1309,7 +1483,8 @@ class BrowseResonancesPopup(BasePopup):
 
     self.cancelAllWaits()
     self.updateWindows()
-    
+    self.updateResWindows()
+
     if resonances and (self.resonances is not None):
       self.resonances = resonances
       if shiftList:
