@@ -392,13 +392,16 @@ class CalcHnHaCouplingPopup(BasePopup):
     bottomButtons = UtilityButtonList(tabbedFrame.sideFrame, expands=True, helpUrl=self.help_url)
     bottomButtons.grid(row=0, column=0, sticky='e')
           
+    self.administerNotifiers(self.registerNotify)
+
+    self.inBody = True
     self.updatePeakLists()
     self.updateJCouplingLists()
     self.updateConstraintSets()
     self.updateKarplusCurve()
     self.updateButtons()
-    self.administerNotifiers(self.registerNotify)
-  
+    self.inBody = False
+
   def administerNotifiers(self, notifyFunc):
   
     for func in ('__init__', 'delete'):
@@ -1237,7 +1240,8 @@ class CalcHnHaCouplingPopup(BasePopup):
         
           for peak, intensity, height, ppm in peaks:
             probability = self.failsafeGetAtomProbability(ccpCode, atomName, ppm)
-            score = intensity * probability
+            # wb104: 10 Aug 2014: added abs() because intensities can be negative
+            score = abs(intensity) * probability
           
             if (best is None) or (score > best[0]):
               best = (score, peak, intensity, height,  ppm)
@@ -1315,9 +1319,12 @@ class CalcHnHaCouplingPopup(BasePopup):
       data.append(datum)   
      
     if invalid:
-      showWarning('Warning',
-                  '%d peaks have an unusable %s value' % (invalid,iType),
-                  parent=self)
+      if self.inBody:
+        print('Warning: %d peaks have an unusable %s value' % (invalid,iType))
+      else:
+        showWarning('Warning',
+                    '%d peaks have an unusable %s value' % (invalid,iType),
+                    parent=self)
        
     return data
 
