@@ -246,7 +246,9 @@ class EditCalculationPopup(BasePopup):
   
     nmrProject = self.nmrProject
     name = askString('Request','Enter name for calculation group', parent=self)
-    name.strip()
+    name = name and name.strip()
+    if not name:
+      return
     
     if nmrProject.findFirstNmrCalcStore(name=name):
       msg = 'Name "%s" already in use for another calculation group' % name
