@@ -294,6 +294,7 @@ class EditPeakListsPopup(BasePopup):
     self.peakList = None
     self.cloneSourceList = None
     self.reproduceSourceList = None
+    self.subtractPeakList = None
     self.peakListTable = None
     self.getShiftDeltasWidget = None
     
@@ -332,7 +333,7 @@ class EditPeakListsPopup(BasePopup):
                                         objects=[c.hex for c in colors],
                                         colors=[c.hex for c in colors])
                                         
-    symbols = ['+','x']                                        
+    symbols = ['+','x','o','*']                                        
     self.peakSymbolWidget = PulldownList(self, callback=self.setSymbol,
                                          texts=symbols)
     
@@ -344,7 +345,7 @@ class EditPeakListsPopup(BasePopup):
                 'The serial number of the peak list, within its spectrum',
                 'Sets whether the peak list is the active one for its spectrum; always "yes" if there is only one list for a spectrum',
                 'The colour to use for the peak cross/symbol and assignment annotation; each list may have a different colour',
-                'The kind of symbol (a small cross on screen) used to indicate picked peak locations for the list',
+                'The kind of symbol (a small mark on the screen) used to indicate picked peak locations for the list',
                 'The number of peaks in the peak list',
                 'The percentage of peak dimensions in the whole peak list that carry assignments',
                 'Whether the peak list is synthetic/simulated; if so, peak assignments in the list have very little influence on chemical shift averages',
@@ -387,12 +388,13 @@ class EditPeakListsPopup(BasePopup):
                 'Delete the selected peak list and all its peaks',
                 'Add a new, blank peak list in the same spectrum as the selected peak list',
                 'Copy the peaks (positions, intensities and assignments) from the selected peak list to another with matching dimensions',
+                'Create a new peak list which contains peaks in the first selected peak list which are not in the second selected peak list, based on position (assignments not copied)',
                 'Move all of the peaks in the selected peak list by specified offsets for each dimension; offsets are prompted']
     texts    = ['Edit Peaks','Delete','Add Sister List',
-                'Copy Peaks','Shift Whole Peak List']
+                'Copy Peaks','Subtract Peaks','Shift Whole Peak List']
     commands = [self.editPeaks,self.deleteList,
                 self.addList,self.reproduceList,
-                self.getShiftDeltas]
+                self.subtractList,self.getShiftDeltas]
     self.peakListButtons  = ButtonList(frameA, texts=texts, tipTexts=tipTexts,
                                        commands=commands, grid=(1,0))
     self.getShiftDeltasButton = self.peakListButtons.buttons[4]                               
@@ -576,6 +578,7 @@ class EditPeakListsPopup(BasePopup):
  
     #self.cloneButton = self.peakListButtons.buttons[3]
     self.reproduceButton = self.peakListButtons.buttons[3]
+    self.subtractButton = self.peakListButtons.buttons[4]
  
     self.waiting = False
     self.update()
@@ -1172,6 +1175,12 @@ class EditPeakListsPopup(BasePopup):
       #self.cloneButton.config(text='Clone Peaks', bg='grey90')
       self.reproduceButton.config(text='Copy Peaks', bg='grey90')
 
+  def cancelSubtract(self):
+  
+    if self.subtractPeakList:
+      self.subtractPeakList = None
+      self.subtractButton.config(text='Subtract Peaks', bg='grey90')
+
   def selectCell(self, peakList, row, col):
   
     self.peakList = peakList
@@ -1235,6 +1244,35 @@ class EditPeakListsPopup(BasePopup):
       self.cancelCopy()
       self.update()
       
+    elif self.subtractPeakList:
+      if self.peakList.dataSource is not self.subtractPeakList.dataSource:
+        showError
+        showError('Different spectra','For now can only subtract peaks from peak list in same spectrum', parent=self)
+
+      N = len(self.subtractPeakList.peaks)
+      if N > 500:
+        if not showOkCancel('Warning','Subtraction is checking %d peaks. This may take some time.' % N, parent=self):
+          self.cancelSubtract()
+          return 
+
+      editPeaksPopup = self.parent.popups.get('edit_peak_list')
+      if editPeaksPopup:
+        editPeaksPopup.turnOffNotifiers()
+      self.turnOffNotifiers()
+      self.subtractButton.config(text='Subtract Peaks', bg='grey90')
+
+      progressBar = ProgressBar(self, text="Subtracting peaks ",total = len(self.subtractPeakList.peaks))
+      peakListNew = PeakBasic.subtractPeakLists(self.subtractPeakList,self.peakList, progressBar=progressBar)
+      progressBar.destroy()
+      
+      if editPeaksPopup:
+        editPeaksPopup.update()
+        editPeaksPopup.turnOnNotifiers()
+        
+      self.turnOnNotifiers()
+      self.cancelSubtract()
+      self.update()
+      
     for button in self.peakListButtons.buttons[0:5]:
       button.enable()
 
@@ -1258,6 +1296,16 @@ class EditPeakListsPopup(BasePopup):
     
     self.cancelCopy()
   
+  def subtractList(self):
+  
+    if self.peakList and not self.subtractPeakList:
+      if showWarning('Info','Now select a list (from same spectrum) to subtract', parent=self):
+        self.subtractPeakList = self.peakList
+        self.subtractButton.config(text='Cancel Subtract', bg='lightBlue')
+        return
+    
+    self.cancelSubtract()
+  
   def shiftPeakList(self, deltas):
   
     if self.getShiftDeltasWidget and self.peakList:
