@@ -65,6 +65,7 @@ from ccp.util.Validation import getModelValidation, storeEnsembleValidation
 from ccpnmr.analysis.popups.BasePopup import BasePopup
 from ccpnmr.analysis.core.StructureBasic import getResiduePhiPsi, makeEnsemble, alignStructures, compareEnsembles
 from ccpnmr.analysis.core.StructureBasic import getStructureFromFile, makePdbFromStructure
+from ccpnmr.analysis.core.StructureBasic import copyModelToEnsemble, makeEmptyEnsembleCopy
 from ccpnmr.analysis.core.ValidationBasic import getEnsembleValidationStore, ANALYSIS_RMSD_CONTEXT
 from ccpnmr.analysis.core.ValidationBasic import RMSD_KEYWORDS
 
@@ -868,7 +869,7 @@ class EditStructuresPopup(BasePopup):
       
       for e1 in empty:
         e1.delete()
-                   
+    
     ensembles.sort()
     ensembles = [x[2] for x in ensembles]
     
@@ -1017,22 +1018,24 @@ class EditStructuresPopup(BasePopup):
 
   def mergeModels(self):
 
-    structures = self.structMatrix.currentObjects
+    ensembles = self.structMatrix.currentObjects
     
-    if structures and self.molSystem:
-      makeEnsemble(structures, replaceStructures=True)
+    if ensembles and self.molSystem:
+      models = [x for y in ensembles for x in y.sortedModels()]
+      if models:
+        makeEnsemble(models, ensemble=models[0].structureEnsemble, 
+                     replaceStructures=True)
     
   
   def splitModels(self):
   
     for ensemble in self.structMatrix.currentObjects:
-      for model in ensemble.models:
-        serials = [model.serial,]
-        makeEnsemble([ensemble,], replaceStructures=False, modelSerials=serials)
+      for model in ensemble.sortedModels():
+        newEnsemble = makeEmptyEnsembleCopy(ensemble)
+        copyModelToEnsemble(newEnsemble, model, identicalEnsembles=True)
         
       ensemble.delete()
  
-      
   def showCoords(self):
   
     self.updateButtons()
@@ -1053,7 +1056,7 @@ class EditStructuresPopup(BasePopup):
     
     self.updateAfter()
 
-  def changeMolSystem2(self, molSystem):
+  def changeMolSystem2(self, molSystem2):
   
     if molSystem2 is not self.molSystem2:
       self.molSystem2 = molSystem2
@@ -1097,7 +1100,7 @@ class EditStructuresPopup(BasePopup):
       self.updateCompareTable()
 
     self.systemPulldown2.setup(texts,molSystems,index)  
-    
+
   def importStructure(self, fileNames=None):
   
     if not fileNames:
@@ -1264,6 +1267,7 @@ class EditStructuresPopup(BasePopup):
       if model is self.model:
         self.after_idle(self.updateCoordsAfter)
         
+  
   def destroy(self):
     
     self.administerNotifiers(self.unregisterNotify)
@@ -1271,39 +1275,46 @@ class EditStructuresPopup(BasePopup):
     BasePopup.destroy(self)
     
   def updateCoords(self, *opt):  
+    """
+    NBNB Displays seqCode but not seqInsertCode 
+    """
     
     model = self.model
     
     objectList  = []
     textMatrix  = []
     
-    i = 0 
     if model:
-      ensemble = self.model.structureEnsemble
+    
+      coordinates = model.coordinates
+      occupancies = model.occupancies
+      bFactors = model.bFactors
       
-      for coordChain in ensemble.sortedCoordChains():
-        chainCode = coordChain.chain.code
+      offset = 0
+      for ii,atom in enumerate(model.structureEnsemble.orderedAtoms):
+      
+        coordResidue = atom.residue
+        chainCode = coordResidue.chain.code
+        seqCode = coordResidue.seqCode
         
-        for coordResidue in coordChain.sortedResidues():
-          seqCode = coordResidue.seqCode
-          residue = coordResidue.residue
-          
-          if residue:
-            ccpCode = residue.ccpCode
-          else:
-            ccpCode = '???'  
-          
-          for coordAtom in coordResidue.sortedAtoms():
-            i += 1
-            coord   = coordAtom.findFirstCoord(model=model)
-            datum   = [i, coordAtom.name, ccpCode,
-                       chainCode, seqCode,
-                       coord.x, coord.y, coord.z,
-                       coord.occupancy, coord.bFactor,
-                       coord.altLocationCode]
-                     
-            objectList.append(coordAtom)         
-            textMatrix.append(datum)
+        residue = coordResidue.residue
+        if residue:
+          ccpCode = residue.ccpCode
+        else:
+          # Should be unnecessary but does not hurt
+          ccpCode = '???'  
+        
+        datum   = [ii, atom.name, ccpCode,
+                   chainCode, seqCode,
+                   coordinates[offset], coordinates[offset+1], 
+                   coordinates[offset+2],
+                   occupancies[ii], bFactors[ii],
+                   atom.altLocationCode]
+        
+        offset += 3
+        
+        objectList.append(atom)         
+        textMatrix.append(datum)
           
     self.coordsMatrix.update(objectList=objectList, textMatrix=textMatrix)
     self.waitingCoords = False
@@ -1432,7 +1443,7 @@ class EditStructuresPopup(BasePopup):
 
     textMatrix  = []
     tipTexts = ['The ensembles']
-    headingList = ['Ensembles']
+    headingList = ['Ensemble Number']
 
     if self.molSystem2:
       compareBackboneOnly = (self.compareRadio.get() == COMPARE_OPTIONS[1])
@@ -1442,7 +1453,7 @@ class EditStructuresPopup(BasePopup):
       for structure1 in structures:
         ensembleId = structure1.ensembleId
         tipTexts.append('Ensemble %d RMSDs' % ensembleId)
-        headingList.append('%d' % ensembleId)
+        headingList.append('RMSD for Ensemble %d' % ensembleId)
         datum = ['%d' % ensembleId]
         for structure2 in structures:
           if structure2 is structure1:
