@@ -390,15 +390,20 @@ class EditWindowPopup(BasePopup):
                 'Whether the negative contour levels are shown in the window for the spectrum',
                 'Whether 1D slices are visible for the spectrum, if any slice displays are active for the window',
                 'Whether contour line in 1D window is visible for the spectrum; if on this helps indicate where peaks would be picked',
-                'Sets how the spectrum dimensions map to corresponding window axes; for a given kind, enables swapping of spectrum dimensions relative to the window']
+                'Sets how the spectrum dimensions map to corresponding window axes; for a given kind, enables swapping of spectrum dimensions relative to the window',
+                'How much the spectrum is offset in the x axis', 'How much the spectrum is offset in the y axis']
     headings = ('Experiment', 'Spectrum', 'Spectrum In\nToolbar',
                 'Pos. Contours\nVisible', 'Neg. Contours\nVisible',
-                'Slice\nVisible', 'Contour Line\nVisible', 'Dim. Mapping')
-    editWidgets = editSetCallbacks = 8 * [None]
+                'Slice\nVisible', 'Contour Line\nVisible', 'Dim. Mapping', 'X Offset', 'Y Offset')
+                
+    self.xAxisOffsetWidget = FloatEntry(self, returnCallback=self.setXAxisOffset, width=5)
+    self.valueAxisOffsetWidget = FloatEntry(self, returnCallback=self.setValueAxisOffset, width=5)
+    
+    editWidgets = editSetCallbacks = 10 * [None] # changed later depending on whether 1D or ND window
     editGetCallbacks = [None, None, self.toggleInToolbar,
                         self.togglePosContoursVisible, self.toggleNegContoursVisible,
                         self.toggleViewSliceVisible, self.toggleContourLineVisible,
-                        self.changeViewMapping ]
+                        self.changeViewMapping, self.getXAxisOffset, self.getValueAxisOffset ]
     self.spectraMatrix = ScrolledMatrix(frameB, headingList=headings,
                                         callback=self.selectSpectrum,
                                         initialRows=5, editWidgets=editWidgets,
@@ -979,8 +984,6 @@ class EditWindowPopup(BasePopup):
   def setTiedAxes(self, obj):
 
     if obj is not None:
-      project = self.project
-      application = project.application
       chosen = self.tiedAxesWidget.get()
       axisPanels = WindowBasic.getPossibleTiedAxisPanels(self.axisPanel)
       tiedAxisPanels = [axisPanel for n, axisPanel in enumerate(axisPanels) if chosen[n]]
@@ -1192,6 +1195,44 @@ class EditWindowPopup(BasePopup):
       if window_popup:
         window_popup.drawAll()
 
+  def getXAxisOffset(self, view):
+
+    application = self.project.application
+    value = WindowBasic.getXAxisOffset(view)
+    self.xAxisOffsetWidget.set(value)
+
+  def setXAxisOffset(self, obj):
+    
+    value = self.xAxisOffsetWidget.get()
+
+    view = self.spectraMatrix.currentObject
+    if view: # should always be true but play safe
+    
+      try:
+        WindowBasic.setXAxisOffset(view, value)
+      
+      except Implementation.ApiError, e:
+        showError('Setting x axis offset', e.error_msg, parent=self)
+ 
+  def getValueAxisOffset(self, view):
+
+    application = self.project.application
+    value = WindowBasic.getValueAxisOffset(view)
+    self.valueAxisOffsetWidget.set(value)
+
+  def setValueAxisOffset(self, obj):
+    
+    value = self.valueAxisOffsetWidget.get()
+
+    view = self.spectraMatrix.currentObject
+    if view: # should always be true but play safe
+    
+      try:
+        WindowBasic.setValueAxisOffset(view, value)
+      
+      except Implementation.ApiError, e:
+        showError('Setting y axis offset', e.error_msg, parent=self)
+ 
   def selectSpectrum(self, specWindowView, row, col):
   
     self.specWindowView = specWindowView
@@ -1268,28 +1309,34 @@ class EditWindowPopup(BasePopup):
     tipTexts4 = ['Whether contour line in 1D window is visible for the spectrum; if on this helps indicate where peaks would be picked']
 
     tipTexts5 = ['Sets how the spectrum dimensions map to corresponding window axes; for a given kind, enables swapping of spectrum dimensions relative to the window']
+    tipTexts6 = ['How much the spectrum is offset in the x axis', 'How much the spectrum is offset in the y axis']
     headings1 = ('Experiment', 'Spectrum', 'Spectrum In\nToolbar')
     headings2 = ('Pos. Contours\nVisible', 'Neg. Contours\nVisible')
     headings3 = ('Slice\nVisible',)
     headings4 = ('Contour Line\nVisible',)
     headings5 = ('Dim. Mapping',)
+    headings6 = ('X Offset', 'Y Offset',)
     editGetCallbacks1 = [None, None, self.toggleInToolbar]
     editGetCallbacks2 = [self.togglePosContoursVisible, self.toggleNegContoursVisible]
     editGetCallbacks3 = [self.toggleViewSliceVisible]
     editGetCallbacks4 = [self.toggleContourLineVisible]
     editGetCallbacks5 = [self.changeViewMapping]
+    editGetCallbacks6 = [self.getXAxisOffset, self.getValueAxisOffset]
 
     if hasValueAxis:
-      tipTexts = tipTexts1 + tipTexts3 + tipTexts4 + tipTexts5
-      headings = headings1 + headings3 + headings4 + headings5
-      editGetCallbacks = editGetCallbacks1 + editGetCallbacks3 + editGetCallbacks4 + editGetCallbacks5
+      tipTexts = tipTexts1 + tipTexts3 + tipTexts4 + tipTexts5 + tipTexts6
+      headings = headings1 + headings3 + headings4 + headings5 + headings6
+      editGetCallbacks = editGetCallbacks1 + editGetCallbacks3 + editGetCallbacks4 + editGetCallbacks5 + editGetCallbacks6
+      n = len(headings) - 2
+      editSetCallbacks = n * [None] + [self.setXAxisOffset, self.setValueAxisOffset]
+      editWidgets = n * [None] + [self.xAxisOffsetWidget, self.valueAxisOffsetWidget]
     else:
       tipTexts = tipTexts1 + tipTexts2 + tipTexts3 + tipTexts5
       headings = headings1 + headings2 + headings3 + headings5
       editGetCallbacks = editGetCallbacks1 + editGetCallbacks2 + editGetCallbacks3 + editGetCallbacks5
-    n = len(tipTexts)
-    editWidgets = editSetCallbacks = n * [None]
-
+      n = len(headings)
+      editWidgets = editSetCallbacks = n * [None]
+    
     textMatrix = []
     objectList = []
     for view in views:
@@ -1310,6 +1357,11 @@ class EditWindowPopup(BasePopup):
           text.append(view.isContourLineVisible and 'Yes' or 'No')
 
         text.append(self.dimMappingString(view))
+        
+        if hasValueAxis:
+          text.append(WindowBasic.getXAxisOffset(view))
+          text.append(WindowBasic.getValueAxisOffset(view))
+          
         textMatrix.append(text)
         objectList.append(view)
       
