@@ -245,12 +245,12 @@ class FollowShiftChangesPopup(BasePopup):
   """
   **Follow Chemical Shift Changes During Titrations**
   
-  This system is desined to efficently extract changing peak position data,
+  This system is designed to efficiently extract changing peak position data,
   which for example may occur during a titration experiment, and then fit the
   chemical shift changes to an equation curve for the extraction of parameters
   that relate to the peak movements. This analysis may be used to measure such
-  things as dissociation constants (e.g. Kd) and temperature coeffients; where
-  the position of or more peaks in a group  of related spectra changes according
+  things as dissociation constants (e.g. Kd) and temperature coefficients; where
+  the position of one or more peaks in a group  of related spectra changes according
   to some experimental condition. Many kinds of experimental condition may be
   varied, but series with changing in concentration (e.g. ligand), temperature
   or pH are commonplace. This system is closely related to the `Follow Intensity
@@ -259,7 +259,7 @@ class FollowShiftChangesPopup(BasePopup):
   intensity.
 
   The general idea is that the user sets up an "NMR series" that contains an
-  array of experiments where each experiment is point in the series and
+  array of experiments where each experiment is one point in the series and
   represents a different value for a parameter (like concentration) being
   investigated. Based initially on the reference peak positions, trajectories
   where picked peak positions move in the different experiments are tracked by
@@ -268,7 +268,7 @@ class FollowShiftChangesPopup(BasePopup):
   are comprised of experiment planes stacked into a higher-dimensionality
   "pseudo-nD" experiment cannot be used in this analysis. The reason for this
   relates to the way that experiments link to chemical shift lists in the CCPN
-  data model; there is no meachanism to record a changing chemical shift within
+  data model; there is no mechanism to record a changing chemical shift within
   a single experiment.
 
   The layout of the popup window is split into two tabs to reduce clutter. The
@@ -276,27 +276,28 @@ class FollowShiftChangesPopup(BasePopup):
   follow the peak positions as they form "trajectories" and do the function
   fitting. The second tab is used to display the results on a table of peak
   groups, where each group corresponds to a series of peaks which have common
-  assignemnts, with one peak for each experiment.
+  assignments, with one peak for each experiment.
 
   The general idea is that the user selects a reference peak list, which will
   give assignment identities to the peak groups being analysed. Typically the
   reference peak list will be from an experiment *in the NMR series*, so that 
-  the the positions of the peaks, as they move in the different experiments,
+  the positions of the peaks, as they move in the different experiments,
   cross or end at the reference position. For proteins this reference will often
   be a 15N HSQC peak list, in which case the analysis operates on peak groups
   that correspond to amides of individual residues. 
 
   The user chooses an NMR series that has been setup in the `NMR Series`_ popup,
-  accessible using the [Edit NMR Series] button. For the anlysis to proceed
+  accessible using the [Edit NMR Series] button. For the analysis to proceed
   properly the selected NMR series will need to contain all of the experiments
-  that form part of the titration/analysis and the vaues of the condition being
+  that form part of the titration/analysis and the values of the condition being
   studied (e.g. concentration) must be correctly set. The "Data List Type" and
   corresponding unit indicate what kind of experimental condition/parameter, as
   dictated by the NMR series, will be fitted to chemical shift distance. The
   "Fitting Function" option is adjusted to say what kind of curve should be
   fitted to the peak intensity data; the linear "Ax + B" is common for
-  temperature coefficents while the elaborate "A((B+4x-sqrt((B+4x)^2-(4x)^2))/4x
-  - C)" is often used to measure dissociation constants. The Error Method
+  temperature coefficients while "A(B+x-sqrt((B+x)^2-4x))" is used for
+  protein-ligand systems in fast exchange, and "A((B+4x-sqrt((B+4x)^2-(4x)^2))/4x - C)"
+  is used for monomer-dimer systems in fast exchange. The Error Method
   determines how the errors in the parameters of the fitted function (e.g. error
   in Kd rate) will be calculated. 
   
@@ -330,13 +331,13 @@ class FollowShiftChangesPopup(BasePopup):
   automatic method is used to find peaks which are not assigned. This automation
   follows the positions of peaks in their trajectories, choosing the best
   combination of peaks that a) roughly follows a straight line and b) fits the
-  selected fuction equation, in terms of the expected chemical shift distance
+  selected function equation, in terms of the expected chemical shift distance
   for the experiment. Having the "Assign groups?" option set means that after
   the first peak grouping, peaks will be linked via assignment and subsequent
   peak searches are not generally required. Peak positions may be tracked in one
   or more spectrum dimensions, according to the "Followed Dimensions" selection.
   When multiple dimensions are used, chemical shift difference for dissimilar
-  istopes are combined using the "Shift Weighting" values. The "Max Step Size"
+  isotopes are combined using the "Shift Weighting" values. The "Max Step Size"
   value are important for the automated peak grouping, given that they limit 
   which peaks are considered when going from one experiment to the next. When
   step sizes are too large the grouping calculation can take a long time. When
@@ -344,7 +345,7 @@ class FollowShiftChangesPopup(BasePopup):
 
   The peak grouping and function fitting is performed using the [Group & Fit
   Peaks] function. After the initial grouping the curve fitting may be
-  redone with via one of the "Re-fit" buttons; this useful if the fitting
+  redone via one of the "Re-fit" buttons; this useful if the fitting
   function is changed. When the curve fitting is done the parameter results from
   the fit, e.g. the "A" and "B" from an "Ax + B" equation, are immediately
   made available from the results table. Also, where relevant, any Kd values are also presented; this requires that the
@@ -355,7 +356,7 @@ class FollowShiftChangesPopup(BasePopup):
   curve-fit worked and whether any adjustments (e.g. in peak picking) need to be
   made or groups removed. See the `Fit Graph`_ documentation for details about
   how the resultant popup window operates. The "Y" value of the curves come
-  from the (isotope weigted) chemical shift distance for each peak of the group
+  from the (isotope weighted) chemical shift distance for each peak of the group
   *along the trajectory from its start point* and the "X" values come from those
   that were entered for the experimental points/planes in the NMR series. When
   the results have been checked, they may be used by directly  exporting the
