@@ -102,7 +102,18 @@ class ViewQualityReportsPopup(BasePopup):
   give a final summary. By default the table represents the atoms in the whole
   of the selected molecular system, but the user may specify only a subset by
   typing the appropriate chain letters and residue ranges into the "Residue
-  Selection" field.
+  Selection" field. Only atoms with element type
+  "H", "C", "N", "P", "F" are considered.
+
+  Explanation of categories, in terms of atom name:
+
+  - (Backbone)N+H: "H" or "N"
+
+  - Backbone+H+HA: "H", "HA", "HA2", "HA3", "C", "CA" or "N"
+
+  - Backbone: "C", "CA" or "N"
+
+  - Side Chain = not (Backbone+H+HA)
 
   **Through-Space Status**
   
@@ -258,7 +269,7 @@ class ViewQualityReportsPopup(BasePopup):
     # Atom 
     #
 
-    frameA.grid_rowconfigure(1, weight=1)
+    frameA.grid_rowconfigure(2, weight=1)
     
     frame = Frame(frameA, grid=(0,0),sticky='ew')
     frame.grid_columnconfigure(4, weight=1)
@@ -278,6 +289,11 @@ class ViewQualityReportsPopup(BasePopup):
     self.residueEntry = Entry(frame, text='', grid=(0,6), tipText=tipText,
                               returnCallback=self.reportAssignStatus)
     
+    text = 'Include water exchangeable atoms'
+    tipText = 'Whether to include water exchangeable atoms in the statistics'
+    self.waterExchangeableCheckButton = CheckButton(frame, grid=(1,0), text=text, tipText=tipText,
+                                                    callback=self.refresh)
+    
     tipTexts = ['The name of a category into which atoms of the selected chain/residue have been grouped',
                 'The total number of atoms (or equivalent sets for methyl groups) that are available for assignment within the category',
                 'The number of atoms (or equivalence groups) that have actually been assigned within the category',
@@ -288,7 +304,7 @@ class ViewQualityReportsPopup(BasePopup):
                 
     headingList = ['Category','Available','Assigned','% Assigned',
                    'Min\nShift','Mean\nShift','Max\nShift']
-    self.atomMatrix = ScrolledMatrix(frameA, headingList=headingList, grid=(1,0),
+    self.atomMatrix = ScrolledMatrix(frameA, headingList=headingList, grid=(2,0),
                                      multiSelect=True, callback=self.selectObject,
                                      tipTexts=tipTexts)
     
@@ -478,7 +494,7 @@ class ViewQualityReportsPopup(BasePopup):
       for clazz in ('ccp.molecule.MolSystem.MolSystem', 'ccp.molecule.MolSystem.Chain'):
         notifyFunc(self.updateMolSystems, clazz, func)
   
-  def refresh(self):
+  def refresh(self, *junk):
   
     self.selectTab(self.tabbedFrame.selected)
         
@@ -546,14 +562,16 @@ class ViewQualityReportsPopup(BasePopup):
   def getRelatedPeaks(self):
 
     peaks = None
-    if self.object:
+    object = self.object
+    if object and type(object) != type(''):
     
       residues = []
     
-      if self.object.className == 'Peak':
+      className = object.className
+      if className == 'Peak':
         peaks = self.peakMatrix.currentObjects
         
-      elif self.object.className == 'Shift':
+      elif className == 'Shift':
         peaks = set()
         shiftList = self.shiftListC
         for shift in self.resonanceMatrix.currentObjects:
@@ -568,13 +586,13 @@ class ViewQualityReportsPopup(BasePopup):
       
         peaks = list(peaks)
       
-      elif self.object.className == 'Residue':
+      elif className == 'Residue':
       
         residues = self.noeMatrix.currentObjects
       
-      elif self.object.className == 'Chain':
+      elif className == 'Chain':
       
-        residues = self.object.residues
+        residues = object.residues
 
       if residues:
       
@@ -710,9 +728,11 @@ class ViewQualityReportsPopup(BasePopup):
     
     if self.molSystemA and self.shiftListA:
       residueSelection = self.getResidueSelection()
+      excludeWaterExchangeable = not self.waterExchangeableCheckButton.get()
       data = analyseAssignmentCompleteness(self.molSystemA,
                                            self.shiftListA,
-                                           residueSelection)
+                                           residueSelection,
+                                           excludeWaterExchangeable)
             
       for datum in data:
       
