@@ -565,7 +565,7 @@ class DyanaFormat(DataFormat):
     
     chemCompVar = self.residue.chemCompVar
     chemComp = chemCompVar.chemComp
-    cifCode = self.findChemCompVarSysName(self.namingSystemName,chemCompVar)
+    cifCode = self.findChemCompVarSysName('CIF',chemCompVar)
     
     if self.useOriginalData and self.origResLabel != None:
       resName = self.origResLabel
@@ -606,9 +606,9 @@ class DyanaFormat(DataFormat):
                                                     seqCode,
                                                     resName,
                                                     '',
-                                                    self.coord.x,
-                                                    self.coord.y,
-                                                    self.coord.z,
+                                                    self.x,
+                                                    self.y,
+                                                    self.z,
                                                     insertionCode = seqInsertCode)
       
     self.coordinateFile.modelCoordinates[self.modelId].append(modelCoordinate)
