@@ -54,8 +54,7 @@ Development of a Software Pipeline. Proteins 59, 687 - 696.
 
 import os, copy
 
-from ccpnmr.format.converters.DataFormat import DataFormat, IOkeywords
-
+from ccpnmr.format.converters.DataFormat import DataFormat, IOkeywords, filteredNameInfo
 from ccp.format.general.Util import getRegularExpressions
 from ccp.general.Io import getDataSourceFileName
 
@@ -446,9 +445,9 @@ class SparkyFormat(DataFormat):
   def setPeakExtras(self):
   
     # Use ppm if available, Hz if not
-    if self.rawPeak.ppm != []:
+    if self.rawPeak.ppm:
       self.unit = 'ppm'
-    elif self.rawPeak.hz != []:
+    elif self.rawPeak.hz:
       self.unit = 'hz'
     else:
       self.unit = None
@@ -681,76 +680,64 @@ class SparkyFormat(DataFormat):
 
     resNameText = ""
 
-    if self.writeAssignments and peakDimContribs != ():
+    #if self.writeAssignments and peakDimContribs != ():
+    if self.writeAssignments and peakDimContribs:
           
       resNames = []
-      resAtomSetNames = []
+      resonanceToAtoms = []
       
+      # get and filter resonanceToAtoms
       for peakDimContrib in peakDimContribs:
       
         if isinstance(peakDimContrib,Nmr.PeakDimContribN):
           print "   Warning: cannot handle multiple resonances for one peakDim contribution. Ignored."
           continue
+        
+        # get resonanceToAtoms
+        ll = self.resonanceToAtoms.get(peakDimContrib.resonance)
+        if ll is None:
+          print ("  Can't handle resonance %s for peak %d" 
+                 % (getResNameText(peakDimContrib.resonance), 
+                 self.peak.serial))
+        else:
+          resonanceToAtoms.extend(ll)
      
-        resonance = peakDimContrib.resonance
-        resName = None
-          
-        if self.resonanceToAtoms.has_key(resonance):
-          
-          for resonanceToAtom in self.resonanceToAtoms[resonance]:
-
-            #
-            # Don't use chainCode for sparky output
-            # Using chain and seqCode mapping for output
-            # Note that code same whether original res names
-            # are being used or not...
-            #
-              
-            chain = resonanceToAtom.chain
-            seqId = resonanceToAtom.seqId
-              
-            seqCode = self.getExportSeqCode(self.chainDict[chain][1],chain.findFirstResidue(seqId = seqId))
-            residueLabel = self.getResidueLabelOneLetter(resonanceToAtom)
-            
-            resName = residueLabel + str(seqCode) + resonanceToAtom.atomName
-          
-            if resName not in resNames:
-              resNames.append(resName)
-            
-            #
-            # Also check atomSet: use this if the same for all...
-            #
-            
-            atomSetId = resonanceToAtom.getAtomSetId()
-
-            if atomSetId:
-            
-              atomName = atomSetId[2]
-            
-              resName = residueLabel + str(seqCode) + atomName
-              
-              if resName not in resAtomSetNames:
-                resAtomSetNames.append(resName)
-
-        if not resName:
-        
-          print "  Can't handle resonance %s" % getResNameText(resonance)
-
-      #
-      # Use atomSet if same for all (and more than one different contrib)
-      #
+      #  sort, filter, and transform
+      if self.presetResonanceMapping:
+        nameInfo = filteredNameInfo(resonanceToAtoms, mode='preset')
+      elif self.compressResonances:
+        nameInfo = filteredNameInfo(resonanceToAtoms, mode='compress')
+      else:
+        nameInfo = filteredNameInfo(resonanceToAtoms)
       
-      if len(resNames) > 1 and len(resAtomSetNames) == 1 and self.compressResonances:
+      # make names
       
-        resNameText = resAtomSetNames[0]
+      for resonanceToAtom, atomName in nameInfo:
+
+        #
+        # Don't use chainCode for sparky output
+        # Using chain and seqCode mapping for output
+        # Note that code same whether original res names
+        # are being used or not...
+        #
+          
+        chain = resonanceToAtom.chain
+        seqId = resonanceToAtom.seqId
+          
+        seqCode = self.getExportSeqCode(self.chainDict[chain][1],chain.findFirstResidue(seqId = seqId))
+        residueLabel = self.getResidueLabelOneLetter(resonanceToAtom)
         
-      elif resNames:
+        resName = residueLabel + str(seqCode) + atomName
         
+        if resName not in resNames:
+          resNames.append(resName)
+
+      if resNames: 
         resNameText = resNames[0]
-          
-        if len(resNames) > 1:      
+      
+        if len(resNames) > 1:   
           print "  Warning: Multiple assignments currently not supported for %s. Only using first one." % self.format
-          
+                
     self.assign.append(resNameText)
       
   def createPeakFilePeak(self):
