@@ -515,7 +515,7 @@ IoSetupList = [
       ['CheckButton','useOriginalData','Use original data:',0,None],
       ['CheckButton','resetMapping','Reset chain mapping:',0,None],
       ['CheckButton','useCcpnChainInfo','Use CCPN chain and sequence codes:',0,None],
-      ['SelectionListWithNone','useFixedAtomSerials','Use format atom serials:',allFormatsDict.keys(),None],
+      #['SelectionListWithNone','useFixedAtomSerials','Use format atom serials:',allFormatsDict.keys(),None],
       ['CheckButton','minimalPrompts','Minimal interaction:',0,None]],
      None,
      None],
