@@ -523,7 +523,10 @@ from ccp.format.general.Util import getRegularExpressions
 ccpPatt = getRegularExpressions()
 
 def getResName(chainCode,seqCode,atomName,seqInsertCode = '',spinSystemId = None, fixChainCode = True):
-  
+  """ NBNB TBD Rsmus July 2012:
+  What happens if atomName is an empty string?
+  Can come about e.g. in Ansig if only sequence is asssigned for a PeakDim
+  """
   if seqCode == None and spinSystemId != None:
     seqCode = "SS%d" % spinSystemId
   
@@ -857,7 +860,7 @@ def getNmrIsotope(proj,elementSymbol):
     
     isotopes = chemElement.sortedIsotopes()
     
-    if isotopes != ():
+    if isotopes:
     
       #
       # For common ones pick the relevant NMR active one
@@ -1120,14 +1123,14 @@ def updateResonanceNamesDict(resonance,resonanceNames,assignFormat = None):
     assignData = ()
 
   # Set ccpn format resonance name if available
-  if assignData == ():
+  if not assignData:
     assignData = resonance.findAllApplicationData(application = ccpNmr_kw, keyword = assign_kw)
 
-    if assignData == ():
+    if not assignData:
       # Default to actual resonance name if nothing else available??!
       resonanceNamesFound.append(resonance.name)
       
-  if assignData != ():
+  if assignData:
     for assignDatum in assignData:
       resonanceNamesFound.append(assignDatum.value)
   
