@@ -424,7 +424,7 @@ class GenericFormatPopup(BasePopup):
  
   def body(self, master):
     
-    if self.components == []:
+    if not self.components:
       showError("Error","No valid %s implemented (yet)." % self.importExportFlag,master)
       self.close()
       
