@@ -57,12 +57,8 @@ software development. Bioinformatics 21, 1678-1684.
 import operator, os, json, sys, subprocess, traceback, time, shutil, tarfile
 from memops.universal import Io as uniIo
 from memops.general import Io as genIo
-from memops.general import Util as genUtil
-from memops.gui.MessageReporter import showYesNo
-
-from ccpnmr.format.converters import DataFormat
-
 from ccpnmr.integrator.core import Util as intUtil
+from ccpnmr.integrator.core import ParameterEditor
 from cyana2ccpn.cyana2ccpn import importFromCyana
 
 propFileName = 'Properties.ccpn.json'
@@ -129,7 +125,7 @@ def makeJsonDict(containerObj, direction='input'):
       intUtil.addParamToDict(name, intUtil.getParameterValue(param), result)
 
   # Data objects
-  paramGroups = []
+  # paramGroups = []
   for datum in containerObj.sortedData():
     if datum.parameterGroup is None or not topLevel:
 
@@ -508,7 +504,7 @@ def parseNumberExpr(selector, startat=1, endat=None):
 
   strs = [x.strip() for x in selector.split(',')]
   if strs[0].startswith('-'):
-    strs[0] = str(stratat)+strs[0]
+    strs[0] = str(startat)+strs[0]
   if strs[-1].endswith('-'):
     if endat is None:
       raise Exception(
@@ -549,17 +545,45 @@ def initRunInteractive(argServer, protocolName=None, prelimProtocolName=None,
   #
   return nmrCalcRun
 
+def initRunDialogue(argServer, protocolName=None, prelimProtocolName=None,
+                        masterRun=None):
+  """ Interactive initialisation of NmrCalc Run starting from protocol names
+  """
+  if masterRun is not None:
+    # copy template run -
+    # e.g. because we have entered data already for multistructure run
+    nmrCalcRun = intUtil.makeDerivedRun(masterRun)
+
+  elif prelimProtocolName is None:
+    nmrCalcRun = None
+
+  else:
+    # First set up using preliminary protocol
+    nmrCalcRun = setupRunDialogue(argServer, protocolName=prelimProtocolName)
+
+  if protocolName is None:
+
+    protocolName = argServer.askString("Program/protocol name", '?')
+
+  nmrCalcRun = setupRunDialogue(argServer, protocolName=protocolName,
+                                   nmrCalcRun=nmrCalcRun)
+  #
+  return nmrCalcRun
+
 def getWmsInteractive(argServer, protocolName=None):
   """ Interactive get WmsProtocol from protocol name
   """
+  from ccp.general.Io import getDataPath
 
   project = argServer.getProject()
 
   entryProtocol = project.findFirstWmsProtocol(name=protocolName)
 
   if entryProtocol is None:
-    print 'Enter name of %s protocol definition file' % protocolName
-    jsonFile = argServer.getFile()
+    dataPath = getDataPath()
+    jsonFile = os.path.join(dataPath,'ccpnmr', 'integrator', protocolName+'.json')
+    # print 'Enter name of %s protocol definition file' % protocolName
+    # jsonFile = argServer.getFile()
     entryProtocol = loadProtocol(project, jsonFile)
   #
   return entryProtocol
@@ -585,6 +609,36 @@ def initNmrCalcRun(entryProtocol, nmrCalcRun=None, nmrCalcStore=None,
   #
   return nmrCalcRun
 
+
+def setupRunDialogue(argServer, protocolName=None, nmrCalcRun=None):
+  """ Interactive set up (if necessary create) nmrCalcRun
+  according to named protocol
+  If nmrCalcRun is passed in, new parameters are added to it.
+  """
+
+  project = argServer.getProject()
+
+  entryProtocol = getWmsInteractive(argServer, protocolName=protocolName)
+
+  nmrCalcRun = initNmrCalcRun(entryProtocol, nmrCalcRun)
+
+  interface = (entryProtocol.findFirstProtocolInterface(name=entryProtocol.name) or
+               entryProtocol.findFirstProtocolInterface())
+  # map to handle protocol/interfaceparameter connections
+  paramMap = {}
+  for ip in interface.sortedInterfaceParameters():
+    pp = ip.protocolParameter
+    if pp in paramMap:
+      raise Exception("Parameter %s in interface twice" % pp)
+    paramMap[pp] = ip
+
+  popup = ParameterEditor.ParameterEditor(argServer.parent, nmrCalcRun, interface, modal=True)
+  nmrCalcRun = popup.run # ParameterEditor sets to None if Cancel button hit; otherwise it is above nmrCalcRun if Ok button hit
+  popup.destroy()
+
+  return nmrCalcRun
+  
+  
 def setupRunInteractive(argServer, protocolName=None, nmrCalcRun=None):
   """ Interactive set up (if necessary create) nmrCalcRun
   according to named protocol
@@ -778,20 +832,22 @@ def makeNmrCalcData(argServer, run, protocolParameter, ioRole='input',
 
   elif paramType == 'constraintLists':
     constraintStore = argServer.getConstraintSet()
-    print "ConstraintList number style: '-4,6,9,11-13,45-'"
-    ss = ','.join(x.serial for x in constraintStore.sortedConstraintLists())
-    selector = argServer.askString("Model selection", ss)
-    if selector == ss:
-      result = run.newConstraintStoreData(
-                      constraintLists=constraintStore.sortedConstraintLists(),
-                      **parDD)
+    if constraintStore:
+      print "ConstraintList number style: '-4,6,9,11-13,45-'"
+      ss = ','.join(str(x.serial) for x in constraintStore.sortedConstraintLists())
+      selector = argServer.askString("Constraint list selection", ss)
+      if selector == ss:
+        result = run.newConstraintStoreData(
+                        constraintLists=constraintStore.sortedConstraintLists(),
+                        **parDD)
+      else:
+        maxClists = max(x.serial for x in constraintStore.constraintLists)
+        clistSerials = parseNumberExpr(selector, startat=1, endat=maxClists)
+        result = run.newConstraintStoreData(nmrConstraintStore=constraintStore,
+                                            constraintListSerials=clistSerials,
+                                            **parDD)
     else:
-      maxClists = max(x.serial for x in constraintStore.constraintLists)
-      clistSerials = parseNumberExpr(selector, startat=1, endat=maxClists)
-      result = run.newConstraintStoreData(nmrConstraintStore=constraintStore,
-                                          constraintListSerials=clistSerials,
-                                          **parDD)
-
+      return
   else:
     raise Exception("Unknown parameter type: %s for %s" %
                     (paramType, protocolParameter))
@@ -810,8 +866,8 @@ def writeDataFiles(nmrCalcRun, targetDir):
   print 'Writing data files to', targetDir
 
   # initialise shared resonanceToAtoms mapping
-  resonanceToAtoms = None
-  fixResonanceToAtoms = None
+  # resonanceToAtoms = None
+  # fixResonanceToAtoms = None
 
   # get I/O handler
   dataIoHandler = intUtil.DataIoHandler(nmrCalcRun.root, nmrCalcRun)
@@ -836,8 +892,8 @@ def writeDataFiles(nmrCalcRun, targetDir):
 
   # write sequence file
   xx = nmrCalcRun.findFirstRunParameter(name='fileFormatSequence')
-  if xx is not None:
 
+  if xx is not None:
     fileFormat = xx.textValue
     fileName = nmrCalcRun.findFirstRunParameter(name='fileNameSequence').textValue
     filePath = uniIo.joinPath(targetDir, fileName)
@@ -873,25 +929,35 @@ def writeDataFiles(nmrCalcRun, targetDir):
                    'IOkeywords',{}).copy()
         keywds.update(myKeywds)
 
-
         if keywds.get('presetResonanceMapping'):
+        # get global resonanceToAtoms map
 
           if 'resonanceToAtoms' not in presetInput:
             # get resonanceToAtoms mapping for presetting
+            namingSystemName = keywds.get('forceNamingSystemName', 'IUPAC')
+            # get nmrConstraintStore
+            constraintData = nmrCalcRun.findFirstData(name='assignment',
+                                           className='ConstraintStoreData')
+            if constraintData:
+              nmrConstraintStore = constraintData.nmrConstraintStore
+            else:
+              constraintStores = set(x.nmrConstraintStore
+                                     for x in nmrCalcRun.findAllData(className='ConstraintStoreData'))
+              if len(constraintStores) == 1:
+                nmrConstraintStore = constraintStores.pop()
+              else:
+                raise Exception("No nmrConstraint not identified in nmrCalcRun")
+
             dd = {}
             for tag in ('individualAtomsIfNoSet', 'individualAtoms',
                         'ignoreChemCompsWithNoSysNames'):
               dd[tag] = keywds[tag]
 
-            # NBNB below commented out because B ROKEN
-            # Likely needs fixing
+            resonanceToAtoms = intUtil.getResonanceAtomMap(namingSystemName, nmrConstraintStore, shiftListObj=obj,
+                                                           **dd)
+            presetInput['resonanceToAtoms'] = resonanceToAtoms
+            # NB resonanceToAtoms has BOTH resonances and fixedResonances as keys
 
-            #tt = intUtil.getResonanceAtomMap(nmrCalcRun, shiftListObj=obj,
-            #                                 **dd)
-            #fixResonanceToAtoms, resonanceToAtoms = tt
-            #presetInput['resonanceToAtoms'] = resonanceToAtoms
-            # NBNB we will need to use fixResonanceToAtoms instead
-            # when we start to write restraint lists
 
           for tag,val in presetInput.items():
             setattr(handler, tag, val)
@@ -905,11 +971,11 @@ def writeDataFiles(nmrCalcRun, targetDir):
 
   # Write data sets
   for dataObj in nmrCalcRun.sortedData():
+    print dataObj.name
     if dataObj.name == 'noesyPeakList':
 
       # write actual peak list
       xx = dataObj.findFirstRunParameter(name='fileFormat')
-      print xx
       if xx is not None:
 
         fileFormat = xx.textValue
@@ -917,7 +983,7 @@ def writeDataFiles(nmrCalcRun, targetDir):
         fileName = dataObj.findFirstRunParameter(name='fileName').textValue
         filePath = uniIo.joinPath(targetDir, fileName)
         peakList = dataObj.peakList
-        dataSource = peakList.dataSource
+        # dataSource = peakList.dataSource
         dataDimRefs = [x.findFirstDataDimRef()
                        for x in peakList.dataSource.sortedDataDims()]
 
@@ -935,9 +1001,40 @@ def writeDataFiles(nmrCalcRun, targetDir):
 
         print '### Done peak', fileName, fileFormat
 
+    elif dataObj.name == 'constraintLists':
+
+      # write actual constraint list
+      xx = nmrCalcRun.findFirstRunParameter(name='restraintFormat')
+      print 'restraintFileObject', xx
+      if xx is not None:
+
+        fileFormat = xx.textValue
+        print 'restraintFileFormat', fileFormat
+        fileNames = [x.textValue for x in dataObj.sortedRunParameters()
+                     if x.name == 'fileName' and x.ioRole == 'input']
+        for ii,constraintList in enumerate(dataObj.constraintLists):
+          filePath = uniIo.joinPath(targetDir, fileNames[ii])
+          constraintTag = constraintList.className[:-14]
+          constraintTag = constraintTag[0].lower() + constraintTag[1:]
+          handler = dataIoHandler.getIoHandler(fileFormat, dataType=constraintTag)
+          keywds = intUtil.getFileFormatData(fileFormat, dataType=constraintTag).get(
+                    'IOkeywords',{}).copy()
+          keywds.update(myKeywds)
+
+          if keywds.get('presetResonanceMapping'):
+            for tag,val in presetInput.items():
+              setattr(handler, tag, val)
+
+          print (' '.join(('### writing', constraintTag, fileName, str(constraintList))))
+          handler.writeConstraints(filePath, constraintList=constraintList, **keywds)
+
+
+
+          print '### Done constraintList', fileName, fileFormat
+
 
 def setupCalculation(nmrCalcRun, targetDir, protocolName=None,
-                     pluginModule=None, doGeneralAdapt=True):
+                     pluginModule=None, doGeneralAdapt=None):
   """ Set up NMR calculation
   """
 
@@ -955,10 +1052,10 @@ def setupCalculation(nmrCalcRun, targetDir, protocolName=None,
   # set env variable for passing
   os.environ['CCPN_CURRENT_RUN'] = targetDir
 
-  if doGeneralAdapt:
+  if doGeneralAdapt is True:
     intUtil.adaptNmrCalcRun(nmrCalcRun)
 
-  pluginModule.Util.adaptNmrCalcRun(nmrCalcRun, protocolName)
+    pluginModule.Util.adaptNmrCalcRun(nmrCalcRun, protocolName)
 
   pluginModule.write.write(nmrCalcRun, targetDir)
 
@@ -991,7 +1088,7 @@ def runSingleInteractive(argServer, protocolName, prelimProtocolName=None,
                       masterRun=None):
   """ Run single protocol for one run
   """
-  executeScript = setupSingleInteractive(argServer, protocolName,
+  executeScript = setupSingleDialogue(argServer, protocolName,
                                        prelimProtocolName,
                                        masterRun)
   if executeScript:
@@ -1031,6 +1128,85 @@ def runCyana2Ccpn(argServer, protocolName, prelimProtocolName=None,
      print 'CCPN not executing %s - no script generated' % protocolName
 
 
+def setupCyana2CcpnDialogue(argServer, protocolName, prelimProtocolName=None,
+                           masterRun=None):
+    nmrCalcRun = setupSingleDialogue(argServer, protocolName=protocolName,
+                                        prelimProtocolName=prelimProtocolName,
+                                        masterRun=masterRun)
+
+    executeScript = prepareSingleRun(nmrCalcRun, protocolName, doGeneralAdapt=True)
+
+def runCyana2CcpnDialogue(argServer, protocolName, prelimProtocolName=None,
+                           masterRun=None):
+    nmrCalcRun = setupSingleDialogue(argServer, protocolName=protocolName,
+                                        prelimProtocolName=prelimProtocolName,
+                                        masterRun=masterRun)
+
+    executeScript = prepareSingleRun(nmrCalcRun, protocolName, doGeneralAdapt=True)
+
+    xx = argServer.askYesNo("Run Calculation")
+    if xx:
+      if executeScript:
+        process = subprocess.call(['python', executeScript])
+        #print 'CCPN executing %s process: %s' % (protocolName,pid)
+        # process.poll()
+        #
+        # if process.returncode is not None:
+        yy = argServer.askYesNo("Import Calculation Results?")
+        if yy:
+          targetDir = nmrCalcDir(nmrCalcRun)
+          importFromCyana(nmrCalcRun,targetDir)
+      else:
+       print 'CCPN not executing %s - no script generated' % protocolName
+    else:
+      pass
+
+def setupPreviousCalculation(argServer, protocolName, prelimProtocolName=None,
+                           masterRun=None):
+
+    currentProject=argServer.getProject()
+    currentNmrCalcStore = currentProject.findFirstNmrCalcStore()
+    masterRun = currentNmrCalcStore.sortedRuns()[-1]
+
+    nmrCalcRun = intUtil.makeDerivedRun(masterRun)
+
+    prepareSingleRun(nmrCalcRun, protocolName, doGeneralAdapt=False)
+
+def runPreviousCalculation(argServer, protocolName, prelimProtocolName=None,
+                           masterRun=None):
+
+    currentProject=argServer.getProject()
+    currentNmrCalcStore = currentProject.findFirstNmrCalcStore()
+    masterRun = currentNmrCalcStore.sortedRuns()[-1]
+
+    nmrCalcRun = intUtil.makeDerivedRun(masterRun)
+
+    executeScript=prepareSingleRun(nmrCalcRun, protocolName, doGeneralAdapt=False)
+
+    if executeScript:
+      process = subprocess.call(['python', executeScript])
+      #print 'CCPN executing %s process: %s' % (protocolName,pid)
+      # process.poll()
+      #
+      # if process.returncode is not None:
+      targetDir = nmrCalcDir(nmrCalcRun)
+      importFromCyana(nmrCalcRun,targetDir)
+    else:
+      print 'CCPN not executing %s - no script generated' % protocolName
+
+
+def importDataFromCyana(argServer):
+
+    targetFile=argServer.getFile()
+    jsonObj=json.load(open(targetFile))
+    currentProject=argServer.getProject()
+    nmrCalcId=jsonObj['CCPN.nmrCalcId']
+    nmrCalcRun = getNmrCalcRunFromId(currentProject, nmrCalcId)
+    targetDir = nmrCalcDir(nmrCalcRun)
+    importFromCyana(nmrCalcRun,targetDir)
+    return nmrCalcRun
+
+
 def setupSingleInteractive(argServer, protocolName, prelimProtocolName=None,
                            masterRun=None):
   """ Set up single protocol for one run
@@ -1041,10 +1217,23 @@ def setupSingleInteractive(argServer, protocolName, prelimProtocolName=None,
                                         prelimProtocolName=prelimProtocolName,
                                         masterRun=masterRun)
 
-  return prepareSingleRun(nmrCalcRun, protocolName)
+  return prepareSingleRun(nmrCalcRun, protocolName, doGeneralAdapt=True)
 
 
-def prepareSingleRun(nmrCalcRun, protocolName):
+def setupSingleDialogue(argServer, protocolName, prelimProtocolName=None,
+                           masterRun=None):
+  """ Set up single protocol for one run
+  """
+
+  # get data
+
+  nmrCalcRun = initRunDialogue(argServer, protocolName=protocolName,
+                                        prelimProtocolName=prelimProtocolName,
+                                        masterRun=masterRun)
+
+  return nmrCalcRun
+
+def prepareSingleRun(nmrCalcRun, protocolName, doGeneralAdapt=None):
   """ Set up single protocol for one run
   """
 
@@ -1054,15 +1243,18 @@ def prepareSingleRun(nmrCalcRun, protocolName):
   # Create target directory. NB must not exist before this point,
   targetDir = nmrCalcDir(nmrCalcRun)
   os.makedirs(targetDir)
-
   outfp = open(uniIo.joinPath(targetDir, setupLogFile),'w')
   print 'Redirecting output to %s' % setupLogFile
 
   try:
     sys.stdout = outfp
 
-    setupCalculation(nmrCalcRun, targetDir=targetDir, protocolName=protocolName,
-                     pluginModule=pluginModule)
+    if doGeneralAdapt is True:
+      setupCalculation(nmrCalcRun, targetDir=targetDir, protocolName=protocolName,
+                       pluginModule=pluginModule, doGeneralAdapt=True)
+    else:
+      setupCalculation(nmrCalcRun, targetDir=targetDir, protocolName=protocolName,
+                       pluginModule=pluginModule, doGeneralAdapt=False)
 
   except:
 
@@ -1089,6 +1281,7 @@ def prepareSingleRun(nmrCalcRun, protocolName):
     print ("WARNING, function 'prepareLocalExecution' not found in %s"
            % pluginModule.__path__)
 
+
 def writeExecuteScript(commandList, targetDir, commandList2, scriptName='ccpnExecute.py', logFile='ccpnCalc.out',
                        protocolName='unspecified'):
   """ Write script to execute commands, and return full script path.
@@ -1148,6 +1341,7 @@ if __name__ == '__main__':
 
 
 
+
 def doPrepareStdWmsRun(nmrCalcRun, pluginModule, targetDir=None):
   """ Prepare for Wms run, starting from command line args (sys.args)
   """
