@@ -55,7 +55,7 @@ software development. Bioinformatics 21, 1678-1684.
 """
 import operator, copy
 
-from memops.general import Io as genIo
+# from memops.general import Io as genIo
 from memops.general import Util as genUtil
 
 from ccp.general import Constants as genConstants
@@ -70,8 +70,9 @@ from ccpnmr.format.converters.XEasyFormat import XEasyFormat
 from ccpnmr.format.converters.NmrViewFormat import NmrViewFormat
 from ccpnmr.format.converters.SparkyFormat import SparkyFormat
 from ccpnmr.format.converters.CyanaFormat import CyanaFormat
-from ccpnmr.format.converters.AnsigFormat import AnsigFormat
-from ccpnmr.format.converters.NmrDrawFormat import NmrDrawFormat
+from ccpnmr.format.converters.CnsFormat import CnsFormat
+# from ccpnmr.format.converters.AnsigFormat import AnsigFormat
+# from ccpnmr.format.converters.NmrDrawFormat import NmrDrawFormat
 
 from ccpnmr.integrator.plugins.Talos.Io import TalosFormat
 from ccpnmr.integrator.plugins.NmrStar.Io import NmrStarWrapper
@@ -102,8 +103,6 @@ _fileFormatData = {
   'seqExt':'seq',
   'shiftExt':'prot',
   'peakExt':'peaks',
-  'upLimitExt':'upl',
-  'loLimitExt':'lol',
   'IOkeywords':{}
  },
  'XEASY':{
@@ -134,6 +133,11 @@ _fileFormatData = {
   'peakExt':'peaks',
   'IOkeywords':{}
  },
+ 'CNS':{
+  'handlerClass':CnsFormat,
+  'constraintExt':'tbl',
+  'IOkeywords':{}
+ },
 }
 
 mainTags =  [x for x in _fileFormatData.keys() if '_' not in x]
@@ -184,6 +188,15 @@ dd = _fileFormatData['CYANA_shift'] =  copy.deepcopy(_fileFormatData['CYANA'])
 dd['IOkeywords']['cyana21Naming'] = True
 dd['handlerClass'] = XEasyFormat
 
+dd = _fileFormatData['CYANA_distance'] =  copy.deepcopy(_fileFormatData['CYANA'])
+dd['IOkeywords']['constraintType'] = 'distance'
+
+dd = _fileFormatData['CYANA_dihedral'] =  copy.deepcopy(_fileFormatData['CYANA'])
+dd['IOkeywords']['constraintType'] = 'dihedral'
+
+dd = _fileFormatData['CYANA_hBond'] =  copy.deepcopy(_fileFormatData['CYANA'])
+dd['IOkeywords']['constraintType'] = 'hBond'
+
 # Non-FormatConverter-using formats
 _fileFormatData['TALOS'] = {
  'handlerClass':TalosFormat,
@@ -334,7 +347,7 @@ class DataIoHandler:
     self.ioHandlers = {}
 
   def getIoHandler(self, dataFormat, dataType=None, reset=False):
-    """ Get IOhandler of approproate type for format and variant.
+    """ Get IOhandler of appropriate type for format and variant.
     NB we want the *same* handler object each time for a given handlerClass
     so that we can reuse the same resonanceToAtoms mapping
     """
@@ -1053,11 +1066,13 @@ def adaptNmrCalcRun(nmrCalcRun):
                                  if x.className in ('ConstraintStoreData',
                                                     'ViolationListData'))
   if constraintStoreSerials:
-    useSerial = max(constraintStoreSerials)
-    for constraintStore in [project.findFirstNmrConstraintStore(serial=x)
-                            for x in constraintStoreSerials]:
-      validateFixedAssignments(constraintStore, nmrProject)
-    mainConstraintStore = project.findFirstNmrConstraintStore(serial=useSerial)
+    # useSerial = max(constraintStoreSerials)
+    mainConstraintStore = project.findFirstNmrConstraintStore(serial=max(constraintStoreSerials))
+    # make sure FixedResonances are mapped to resonances(set FixedResonance.resonanceSerial)
+    linkFixedResonancesToResonances(mainConstraintStore)
+    print '### validating for constraintStore: ', mainConstraintStore.serial
+    validateFixedAssignments(mainConstraintStore, nmrProject)
+
   else:
     mainConstraintStore = project.newNmrConstraintStore(
                                    nmrProject=nmrProject)
@@ -1081,7 +1096,28 @@ def adaptNmrCalcRun(nmrCalcRun):
   peakListObjs = [x for x in nmrCalcRun.sortedData()
                   if x.className == 'PeakListData']
 
-  peakFiles = []
+
+  # make file names for constraintLists
+  # get constraintList data object
+  for xx in nmrCalcRun.sortedData():
+    if (xx.className == 'ConstraintStoreData' and xx.ioRole == 'input'
+        and xx.name == 'constraintLists'):
+      constraintListData = xx
+      break
+  else:
+    constraintListData = None
+
+  if constraintListData and restraintFormat:
+    # NBNB file extensions are added later, since they depend on both list and program type.
+    for constraintList in constraintListData.constraintLists:
+      constraintTag = constraintList.className[:-14]
+      constraintTag = constraintTag[0].lower() + constraintTag[1:]
+      fileName = '%s_%s.%s' % (constraintTag, constraintList.serial,
+                               constraintFileExtension(constraintList, restraintFormat))
+      nmrCalcRun.newRunParameter(name='fileName', textValue=fileName,
+                                 code='fileName', data=constraintListData)
+
+  # peakFiles = []
   for peakListData in peakListObjs:
     if peakFormat is not None:
       nmrCalcRun.newRunParameter(name='fileFormat', textValue=peakFormat,
@@ -1100,6 +1136,18 @@ def adaptNmrCalcRun(nmrCalcRun):
                           measurementList=shiftList)
         shiftListObjs.append(shiftListData)
 
+  # If there are still no shiftLists, take the first non-empty one - we want at least one
+  if not shiftListObjs:
+    for shiftList in nmrCalcRun.nmrCalcStore.nmrProject.sortedMeasurementLists():
+      if shiftList.measurements and shiftList.className == 'ShiftList':
+        shiftLists.add(shiftList)
+        shiftListObjs.append(nmrCalcRun.newMeasurementListData(name='shiftList',
+                             measurementList=shiftList))
+        break
+    else:
+      print('WARNING, no shift lists found')
+
+
   if shiftFormat is not None:
     for shiftListData in shiftListObjs:
       nmrCalcRun.newRunParameter(name='fileFormat', textValue=shiftFormat,
@@ -1111,10 +1159,7 @@ def adaptNmrCalcRun(nmrCalcRun):
                                  code='fileName', data=shiftListData)
 
 
-
   # copy shiftlists to main constraintstore
-  # NBNB change: have a ChemShiftConstraintList for every shiftlist
-  # regardless if it is coverd by, say, a cistanceRestraintList
   resMapDict = mainConstraintStore.quickResonances
   for shiftList in shiftLists:
     #ll = [x for x in mainConstraintStore.constraintLists
@@ -1122,7 +1167,7 @@ def adaptNmrCalcRun(nmrCalcRun):
                                          className='ChemShiftConstraintList')
           if shiftList in x.measurementLists]
     if not ll:
-      # make ChemShiftConstraintList if shiftList is not alredy covered
+      # make ChemShiftConstraintList
       shiftConstraintList = mainConstraintStore.newChemShiftConstraintList(
         measurementLists=[shiftList], name=shiftList.name, unit=shiftList.unit)
       assignStoreData.addConstraintListSerial(shiftConstraintList.serial)
@@ -1157,6 +1202,7 @@ def validateFixedAssignments(constraintStore, nmrProject):
         # Weird error. Surely we wannot assume that serials are the same?
         #     resonanceSerial is the correct attribute
         res = resonances.get(fres.resonanceSerial)
+        print(res)
         if res:
           resSet = res.resonanceSet
           if resSet:
@@ -1244,59 +1290,37 @@ def getAmalgamatedTolerances(dataSources, defPoints, minTol,
   return result
 
 
-def getResonanceAtomMap(nmrCalcRun, shiftListObj=None, **keywds):
-  """Get resonanceToAtoms mapping.
-  Relies on 'atomNamingSystem' RunParameter and 'assignment' ConstraintStoreData
-  """
+def getResonanceAtomMap (namingSystemName, nmrConstraintStore, shiftListObj=None, **keywds):
+  """Get map from resonance AND fixedresonances to ResonanceAtom objects,
+  compressing atom names depending on parameters"""
 
-  # get naming system name
-  obj = nmrCalcRun.findFirstRunParameter(name='atomNamingSystem', data=None)
-  if not obj:
-    raise Exception("No 'atomNamingSystem' RunParameter in nmrCalcRun")
-  namingSystemName = obj.textValue
+  fixedResonances = nmrConstraintStore.sortedFixedResonances()
+  resonanceToAtoms = DataFormat.getResonanceAtomMap(namingSystemName,
+                                                    fixedResonances, **keywds)
 
-  # get std assignmentStore
-  obj = nmrCalcRun.findFirstData(name='assignment',
-                                 className='ConstraintStoreData')
-  if not obj:
-    raise Exception("No 'assignment' ConstraintStoreData in nmrCalcRun")
-  assignmentStore = obj.nmrConstraintStore
-  resonances = assignmentStore.sortedFixedResonances()
-
-  fixResonanceToAtoms = DataFormat.getResonanceAtomMap(namingSystemName,
-                                                       resonances, **keywds)
-  if shiftListObj:
-    shiftListSerial  = shiftListObj.measurementList.serial
-    for constrList in assignmentStore.sortedConstraintLists():
-      if (constrList.className == 'ChemShiftConstraintList'
-          and shiftListSerial in constrList.measureListSerials):
-        shiftConstrList = constrList
-        break
-    else:
-      shiftConstrList = None
-
-    if not keywds.get('individualAtoms'):
-      compressAssignments(fixResonanceToAtoms, shiftConstrList)
+  if shiftListObj and not keywds.get('individualAtoms'):
+    compressAssignments(resonanceToAtoms, shiftListObj)
 
   # Convert from fixed to real resonances
 
-  # make fixedrs - res map
+  # make fixedres - res map
   fresMap = {}
-  nmrProject = nmrCalcRun.nmrCalcStore.nmrProject
-  for fres,val in fixResonanceToAtoms.items():
+  nmrProject = nmrConstraintStore.nmrProject
+  for fres,val in resonanceToAtoms.items():
     res = nmrProject.findFirstResonance(serial=fres.resonanceSerial)
     if res is None:
       vv = val[0]
       ss =   '%s.%s.%s - %s' % (vv.chain.code, vv.seqId, vv.atomName or '',
                                 vv.atomSetName or '')
-      print ("WARNING, no match for FixedResonance %s, (%s) - Skipping"
+      print ("WARNING, no resonance match for FixedResonance %s, (%s) - Skipping"
              % (fres.serial, ss))
     else:
       fresMap[fres] = res
 
-
   resonanceToAtoms = {}
-  for fres, val in fixResonanceToAtoms.items():
+  items = list(resonanceToAtoms.items())
+  # NB we must make seaprate list as we are modifying teh dictionary during the loop
+  for fres, val in items:
     res = fresMap.get(fres)
     if res is not None:
       resonanceToAtoms[res] = ll = []
@@ -1309,26 +1333,6 @@ def getResonanceAtomMap(nmrCalcRun, shiftListObj=None, **keywds):
           setattr(newR2a, tag, mm)
 
 
-  #
-  # Debug code...
-  #
-
-  #printList = []
-  #for res in sorted(resonanceToAtoms, key=operator.attrgetter('serial')):
-  #  ll = [(rta.chain and rta.chain.code, rta.seqId, rta.atomName,
-  #         rta.atomSetName,rta.chemAtom and rta.chemAtom.name, rta.chemAtomSet and rta.chemAtomSet.name)
-  #        for rta in resonanceToAtoms[res]]
-  #  ll2 = [ll, res.serial, res.name, len(ll)]
-  #  printList.append(ll2)
-
-  #printList.sort()
-
-  #for ll in printList:
-  #  print   '~~~', ll[1], ll[2], ll[3], ['%s.%s.%s.%s.%s.%s' % tt for tt in ll[0]]
-
-  #
-  return fixResonanceToAtoms, resonanceToAtoms
-
 def compressAssignments(resToAtoms, shiftValueList=None, tolerance=None):
   """ Modify resToAtoms in place
   so that resonanceSets with degenerate or unknown shifts keep their atomSets
@@ -1482,7 +1486,7 @@ def makeDerivedRun(masterRun):
       if obj.ioRole == 'output':
         obj.delete()
 
-  # NBNB TODO consier changing this later
+  # NBNB TODO consider changing this later
   # For now, avoid nested master run (not allowed by model
   while masterRun.masterRun is not None:
     masterRun = masterRun.masterRun
@@ -1491,3 +1495,94 @@ def makeDerivedRun(masterRun):
 
   #
   return nmrCalcRun
+
+
+def constraintFileExtension(constraintList, fileFormat=None, lowerLimit=False):
+  """Get extension for constraint file.
+  code in seperate function as the problem is ocmplex for definition dictionaries"""
+
+  if 'CYANA' in fileFormat.upper():
+    if lowerLimit:
+      return 'lol'
+    elif constraintList.className == "DihedralConstraintList":
+      return 'aco'
+    else:
+      return 'upl'
+
+  else:
+    # Default extension - used whenever nothing specific is known
+    return 'tbl'
+
+def linkFixedResonancesToResonances(constraintStore):
+  """Match assigned FixedResonances to assigned Resonances
+  based on shared atoms assignment and set resonanceSerial to link them"""
+  nmrProject = constraintStore.nmrProject
+  # atoms2Resonance = []
+  atoms2ResonanceSets = []
+  for resonanceSets in (constraintStore.sortedFixedResonanceSets(),
+                        nmrProject.sortedResonanceSets()):
+    # a2Res = {}
+    # atoms2Resonance.append(a2Res)
+    a2ResSet = {}
+    atoms2ResonanceSets.append(a2ResSet)
+    for resonanceSet in resonanceSets:
+      atoms = frozenset(x for y in resonanceSet.atomSets for x in y.atoms)
+      ll = a2ResSet.get(atoms)
+      if ll is None:
+        a2ResSet[atoms] = [resonanceSet]
+      else:
+        ll.append(resonanceSet)
+
+
+  # print('### TOTALS resSets %s; fresSets %s'
+  #       % (len(nmrProject.resonanceSets), len(constraintStore.fixedResonanceSets)))
+
+  for atoms, fresonanceSets in atoms2ResonanceSets[0].items():
+    resonanceSets = atoms2ResonanceSets[1].get(atoms, ())
+    # ll = [sorted(x.serial for y in resonanceSets for x in y.resonances)]
+    # fll = [sorted(x.serial for y in fresonanceSets for x in y.resonances)]
+    # print("### res %s; fres %s, EQSERIALS %s"
+    #       % (ll, fll, ll==fll))
+
+    if len(resonanceSets) == len(fresonanceSets):
+      if len(resonanceSets) == 1:
+        resonances = list(resonanceSets)[0].sortedResonances()
+        fresonances = list(fresonanceSets)[0].sortedResonances()
+        fresonance = fresonances[0]
+        if len(resonances) == len(fresonances):
+          if len(resonances) == 1:
+            if fresonance.resonanceSerial is None:
+              # print("### FIXED - atoms %s, sets:1-1" %
+              #       [x.name for x in atoms])
+              fresonance.resonanceSerial = resonances[0].serial
+            # elif fresonance.resonanceSerial == resonances[0].serial:
+            #   print("### WASOK - atoms %s, sets:1-1" %
+            #         [x.name for x in atoms])
+            # else:
+            #   print("### ASSMISMATCH - atoms %s, sets:1-1" %
+            #        [x.name for x in atoms])
+    #       else:
+    #         print('### MULTIRES OK:%s fres %s fatomset %s res %s atomset %s' %
+    #               ([x.name for x in fresonances], not [x for x in fresonances if x.resonanceSerial is None],
+    #               [x.name for y in fresonanceSets[0].sortedAtomSets() for x in y.sortedAtoms()],
+    #               [x.name for x in resonances],
+    #               [x.name for y in resonanceSets[0].sortedAtomSets() for x in y.sortedAtoms()],
+    #               ))
+    #
+    #     else:
+    #       print("### RESMISMATCH - atoms %s, res:%s-%s; frnames: %s, names:%s" %
+    #             ([x.name for x in atoms], len(resonances), len(fresonances),
+    #              [x.name for x in fresonances],
+    #              [x.name for x in resonances]
+    #             ))
+    #   else:
+    #
+    #     print("### MULTISET - atoms %s, set:%s-%s; " %
+    #           ([x.name for x in atoms], len(resonanceSets), len(fresonanceSets)))
+    #
+    # else:
+    #   print("### SETMISMATCH - residue %s atoms %s, set:%s-%s; OKsets %s " %
+    #         (list(atoms)[0].residue.seqId, [x.name for x in atoms], len(resonanceSets), len(fresonanceSets),
+    #         [not[x for x in y.resonances if x.resonanceSerial is None] for y in fresonanceSets]))
+
+
