@@ -20,22 +20,16 @@ Imports structure(s) into the CCPN project using a CCPN routine
 
 """
 
-from memops.general.Io import loadProject, saveProject
-from ccpnmr.analysis.core.ExperimentBasic import setRefExperiment
 import CyanaParser.CyanaParser as cp
-from cing.core.molecule import Resonance
-from ccpnmr.analysis.core.PeakBasic import pickPeak, makePeakListFromShifts, setManualPeakIntensity
-from ccpnmr.analysis.core.MoleculeBasic import getResidueMapping as grm
-from ccpnmr.analysis.core.AssignmentBasic import assignResToDim, addSpinSystemResonance, assignAtomsToRes
-from ccpnmr.analysis.core.ConstraintBasic import makeStructureGeneration, getFixedResonance, updateFixedResonance
+from ccpnmr.integrator.core import Util as intUtil
+from ccpnmr.analysis.core.PeakBasic import pickPeak, setManualPeakIntensity, copyPeakList
+from ccpnmr.analysis.core.AssignmentBasic import assignResToDim, assignAtomsToRes
+from ccpnmr.analysis.core.ConstraintBasic import makeStructureGeneration, getFixedResonance
 from ccp.lib.StructureIo import getStructureFromFile
-from ccp.util.Molecule import addMolResidues
 from ccpnmr.analysis.core.ExperimentBasic import cloneExperiment, setExperimentShiftList
 from ccpnmr.format.converters.DataFormat import getResonanceAtomMap
-from ccpnmr.integrator.plugins import Cyana as cyanaPlugin
 import os
 import json
-import time
 
 
 
@@ -52,11 +46,13 @@ def importFromCyana(nmrCalcRun, targetDir):
   rdcFiles = []
   cyaFiles = []
   noaFiles = []
+  txtFiles = []
 
   ccpnConfigFile = open("Properties.ccpn.json")
   ccpnConfig = json.load(ccpnConfigFile)
   configFile = open("cyana2ccpn.json")
   config = json.load(configFile)
+  runId = ccpnConfig['CCPN.nmrCalcId'].split('+')[1]
 
 
   for peakList in ccpnConfig['PeakListData']:
@@ -79,7 +75,7 @@ def importFromCyana(nmrCalcRun, targetDir):
 
   c.parse(seqFile=seqFile, originalProtFile=originalProtFile,
           finalProtFile=finalProtFile, peakFiles=peakFiles,
-          uplFiles=uplFiles,rdcFiles=rdcFiles,
+         rdcFiles=rdcFiles,
           acoFiles=acoFiles, cyaFiles=cyaFiles,noaFiles=noaFiles)
   nmrProject = rootProject.currentNmrProject
   nmrConstraintStore = rootProject.newNmrConstraintStore(nmrProject=nmrProject)
@@ -97,23 +93,33 @@ def importFromCyana(nmrCalcRun, targetDir):
                                            AnalysisProject, nmrConstraintStore)
   loadPdb(config['pdbFile'], molSystem)
 
-
+  # newPeakLists = []
   for peakList in ccpnConfig['PeakListData']:
     peakListName = peakList['fileName'].split('.peaks')[0]
     experimentSerial = int(peakList['fileName'].split('_')[1])
     ccpnExperiment = nmrProject.findFirstExperiment(serial=experimentSerial)
-    cloneName = ccpnExperiment.name + '_clone'
+    cloneName = ccpnExperiment.name + '_run' + str(runId)
     clonedExperiment = cloneExperiment(ccpnExperiment, cloneName)
     spectrum = clonedExperiment.findFirstDataSource()
     setExperimentShiftList(clonedExperiment, newShiftList)
     peakList = spectrum.newPeakList()
     spectrum.activePeakList = peakList
+
     for cingPeakList in c.peakLists:
 
       if cingPeakList.name.split('-')[0] == peakListName:
         peakList.name = cingPeakList.name
         pickPeaksFromCing(cingPeakList, peakList, resonanceDictionaries['resonanceDict'])
         nmrCalcRun.newPeakListData(name=cingPeakList.name, ioRole='output', peakList=peakList)
+        # newPeakLists.append(peakList)
+
+
+    # for newPeakList in newPeakLists:
+    assignedPeakList = spectrum.newPeakList()
+    unassignedPeakList = spectrum.newPeakList()
+    assignedPeakList.details = 'assigned'
+    unassignedPeakList.details = 'unassigned'
+    splitAssignedUnassigned(peakList, assignedPeakList, unassignedPeakList)
 
   loadChemShiftRestraints(c.chemicalShiftRestraints, originalProtFile, nmrConstraintStore, atomToResonanceMap,
                           resonanceDictionaries['fixedResonanceDict'], molSystem)
@@ -123,9 +129,15 @@ def importFromCyana(nmrCalcRun, targetDir):
                            resonanceDictionaries['cingFixedResonanceDict'],molSystem, AnalysisProject)
 
   if len(c.violationLists) != 0:
-    loadViolatedDistanceRestraints(c.violationLists, nmrProject, nmrCalcRun, nmrConstraintStore,
+    violatedPeaks = loadViolatedDistanceRestraints(c.violationLists, nmrProject, nmrCalcRun, nmrConstraintStore,
                            resonanceDictionaries['fixedResonanceDict'],
                            resonanceDictionaries['cingFixedResonanceDict'],molSystem, AnalysisProject)
+    for peakList,peaks in violatedPeaks.iteritems():
+      spectrum = peakList.getDataSource()
+      newPeakList = spectrum.newPeakList()
+      newPeakList.details = 'violated'
+      copyPeakList(peakList, newPeakList, peaks=peaks)
+
 
   if len(c.dihedralRestraintLists) != 0:
     loadDihedralRestraints(c.dihedralRestraintLists,nmrConstraintStore, nmrCalcRun,
@@ -134,12 +146,30 @@ def importFromCyana(nmrCalcRun, targetDir):
   if len(c.rdcRestraintLists) != 0:
     loadRdcRestraints(c.rdcRestraintLists,nmrConstraintStore,
                       resonanceDictionaries['cingFixedResonanceDict'], molSystem)
-  cyanaPlugin.read.read(nmrCalcRun, targetDir)
+
+  pluginModule = intUtil.getIntegratorPlugin(ccpnConfig["CCPN.Run.wmsProtocolName"])
+  pluginModule.read.read(nmrCalcRun, targetDir)
+  # print dir(Cyana.read)
   print "Import Complete"
 
 
 
 
+def splitAssignedUnassigned(peakList, assignedPeakList, unassignedPeakList):
+
+  assignedPeaks = []
+  unassignedPeaks = []
+  for peak in peakList.peaks:
+    contribs =  peak.sortedPeakContribs()
+    if len(contribs) > 0:
+      assignedPeaks.append(peak)
+    else:
+      unassignedPeaks.append(peak)
+
+  copyPeakList(peakList, assignedPeakList, peaks=assignedPeaks)
+  copyPeakList(peakList, unassignedPeakList, peaks=unassignedPeaks)
+
+
 def createAtomtoResonanceMap(nmrProject):
   atomToResonanceMap = {}
   resonanceToAtomMap = getResonanceAtomMap('IUPAC', nmrProject.sortedResonances())
@@ -234,8 +264,12 @@ def assignResonances(resonances, atomToResonanceMap,molSystem, ccpnShiftList, An
 
 def pickPeaksFromCing(cingPeakList, peakList, resonanceDict):
 
+
   for cingPeak in cingPeakList:
-    peak = pickPeak(peakList, cingPeak.positions, unit='ppm', doFit=False)
+    peakList.root.override = True
+    peak = pickPeak(peakList, cingPeak.positions, unit='ppm', doFit=False,
+                    serial=cingPeak.xeasyIndex)
+    peakList.root.override = False
     setManualPeakIntensity(peak, value=cingPeak.height.value, intensityType="height")
     if len(peak.peakDims) == len(cingPeak.resonances):
       for j, peakDim in enumerate(peak.sortedPeakDims()):
@@ -264,13 +298,14 @@ def loadPdb(filename, molSystem):
   makeStructureGeneration(structure)
   print "Structures loaded"
 
-def loadDistanceRestraints(cingRestraintList, nmrProject, nmrCalcRun, nmrConstraintStore, fixedResonanceDict, cingFixedResonanceDict,molSystem, AnalysisProject):
+def loadDistanceRestraints(cingRestraintList, nmrProject, nmrCalcRun, nmrConstraintStore,
+                           fixedResonanceDict, cingFixedResonanceDict,molSystem, AnalysisProject):
   for cingList in cingRestraintList:
     name = cingList.name
     distanceRestraintList = nmrConstraintStore.newDistanceConstraintList(name=name)
     for cingRestraint in cingList:
 
-      restraint = distanceRestraintList.newDistanceConstraint(upperLimit=cingRestraint.upper, lowerLimit=cingRestraint.lower)
+      restraint = distanceRestraintList.newDistanceConstraint(upperLimit=float(cingRestraint.upper), lowerLimit=cingRestraint.lower)
       for atoms in cingRestraint.atomPairs:
         ccpnFixedResonances = [[], []]
         for i, atom in enumerate(atoms):
@@ -302,7 +337,10 @@ def loadDistanceRestraints(cingRestraintList, nmrProject, nmrCalcRun, nmrConstra
 
         for fr1 in ccpnFixedResonances[0]:
           for fr2 in ccpnFixedResonances[1]:
-            restraint.newDistanceConstraintItem(resonances=[fr1, fr2])
+            try:
+              restraint.newDistanceConstraintItem(resonances=[fr1, fr2])
+            except:
+              pass
       ccpnPeaks=set()
       for ccpnExperiment in nmrProject.experiments:
         try:
@@ -321,12 +359,14 @@ def loadDistanceRestraints(cingRestraintList, nmrProject, nmrCalcRun, nmrConstra
 
 def loadViolatedDistanceRestraints(cingRestraintList, nmrProject, nmrCalcRun, nmrConstraintStore,
                                    fixedResonanceDict, cingFixedResonanceDict,molSystem, AnalysisProject):
+  violatedPeaks = {}
   for cingList in cingRestraintList:
     name = cingList.name+"_violated"
+
     distanceRestraintList = nmrConstraintStore.newDistanceConstraintList(name=name)
     for cingRestraint in cingList:
 
-      restraint = distanceRestraintList.newDistanceConstraint(upperLimit=cingRestraint.upper,lowerLimit=cingRestraint.lower)
+      restraint = distanceRestraintList.newDistanceConstraint(upperLimit=float(cingRestraint.upper),lowerLimit=cingRestraint.lower)
       for atoms in cingRestraint.atomPairs:
         ccpnFixedResonances = [[], []]
         for i, atom in enumerate(atoms):
@@ -362,18 +402,28 @@ def loadViolatedDistanceRestraints(cingRestraintList, nmrProject, nmrCalcRun, nm
       for ccpnExperiment in nmrProject.experiments:
         try:
           spectrum = ccpnExperiment.findFirstDataSource()
-          peak = spectrum.findFirstPeakList(name=cingRestraint.peakList).findFirstPeak(serial=int(cingRestraint.peak))
+          peakList = spectrum.findFirstPeakList(name=cingRestraint.peakList)
+          peak = peakList.findFirstPeak(serial=int(cingRestraint.peak))
           ccpnPeaks.add(peak)
+          if peak is not None:
+            ll = violatedPeaks.get(peakList)
+            if ll is None:
+              violatedPeaks[peakList] = [peak]
+            else:
+              ll.append(peak)
         except (AttributeError, TypeError):
           pass
       if None not in ccpnPeaks:
         restraint.setPeaks(ccpnPeaks)
+
     nmrCalcRun.newConstraintStoreData(name=name, ioRole='output',constraintStoreSerial=nmrConstraintStore.serial)
 
-
-
   print "Violations assigned"
 
+  return violatedPeaks
+
+
+
 def loadDihedralRestraints(cingRestraintList, nmrConstraintStore, nmrCalcRun, cingFixedResonanceDict, molSystem):
   for cingList in cingRestraintList:
     name = cingList.name
