@@ -89,7 +89,8 @@ versionMap['2.1.2'] = versionMap['s']
 
 cvsWorkingDir = 'ccpn'
 
-svnWorkingDir = 'work'
+#svnWorkingDir = 'work'
+svnWorkingDir = 'ccpn'
 
 class Version:
 
@@ -242,6 +243,10 @@ def getRepositoryDir(versionTag, repoTag=None):
   extraDirs is one or more directories as given in the versionMap
   """
   
+  if versionTag == '3.0.a1':
+    # special case - different directory structure
+    return os.path.join(os.environ.get('CCPN_MODEL'), 'trunk', 'ccpn', 'ccpnmodel', 'v_3_0_a1')
+  
   progCode, extraDirs = versionMap[versionTag]
   
   if not repoTag:
@@ -258,6 +263,7 @@ def getRepositoryDir(versionTag, repoTag=None):
   
   else:
     # get svn directory
+
     ll = [os.environ.get('CCPN_SVNROOT'), repoTag]
     ll.extend(extraDirs)
     ll.append('ccpn')
