@@ -263,6 +263,7 @@ def makeCcpnProject(entryName):
       raise Exception("NO extracted CCPN project in %s" % path)
     ccpnProject = genIo.loadProject(ppath, suppressGeneralDataDir=True)
     
+    
     # neutralize any other pending CASD-NMR projects
     casdRun = casdUtil.prepareNmrCalcRun(ccpnProject, 'CING')
     for run in casdRun.nmrCalcStore.findAllRuns(status='pending'):
@@ -278,7 +279,7 @@ def makeCcpnProject(entryName):
       tmpstruc = os.path.join(tmpdir, 'structures')
       src = casdUtil.getInputFile(entryName, 'structures')
       casdUtil.extractCompressedFile(src, tmpstruc, entryName, okExts=('pdb',))
-      tmpstruc = casdUtil.getLowestSubDir(tmpstruc)
+      tmpstruc = casdUtil.getLowestSubDir(tmpstruc, followDirs=('cns_format',))
       structureFiles = os.listdir(tmpstruc)
  
  
@@ -300,7 +301,7 @@ def makeCcpnProject(entryName):
       # dataIo version
       #fcw = None
       
-      if False and structureFiles:
+      if structureFiles:
         # NBNB uses Rasmus in-development trunk structure reading.
         # WOrks well. Temporarily disabled
         # read in structures
@@ -316,7 +317,9 @@ def makeCcpnProject(entryName):
  
         pdbPaths = [os.path.join(tmpstruc,x) for x in pdbFiles]
         
-        if fcw is None:
+        if True:
+        #if fcw is None:
+	      #Always use dataIo version
           # dataIo version
           ensemble = StructureIo.getStructureFromFiles(
                                  ccpnProject.findFirstMolSystem(), pdbPaths)
@@ -395,11 +398,7 @@ def makeCcpnProject(entryName):
 
     finally:
         shutil.rmtree(tmpdir, ignore_errors=True)
-    
-    # debug:
-    for ee in ccpnProject.sortedStructureEnsembles():
-      print '@@@', [getattr(ee,x) for x in ('ensembleId','isLoaded','isModified',
-                     'createdBy','guid','molSystem',)]
+        pass
     
     # rename and package project
     ccpnOutputDir = os.path.join(dataDir, entryName)
