@@ -18,9 +18,6 @@ from ccpnmr.analysis.core.ConstraintBasic import getPeakDimTolerance
 from ccpnmr.analysis.core.ExperimentBasic import getOnebondDataDims, getDataDimIsotopes, findSpectrumDimsByIsotope
 from ccpnmr.analysis.core.ExperimentBasic import getThroughSpacePeakLists, getDataDimRefFullRange, getPrimaryDataDimRef
 from ccpnmr.analysis.core.MarkBasic import createNonPeakMark
-from ccpnmr.analysis.core.MoleculeBasic import getNumConnectingBonds, areResonancesBound, getBoundAtoms
-from ccpnmr.analysis.core.StructureBasic import getAtomSetCoords
-from ccpnmr.analysis.core.StructureBasic import getAtomSetsDistance
 from ccpnmr.analysis.core.Util import getAnalysisDataDim, getDataDimAssignmentTolerance
 from ccpnmr.analysis.core.Util import getAnalysisPeakList
 from ccpnmr.analysis.core.WindowBasic import getDataDimAxisMapping, getWindowPaneName
@@ -28,6 +25,9 @@ from ccpnmr.analysis.core.PeakBasic import pickPeak, setupPeak
 from ccpnmr.analysis.frames.PeakTableFrame import PeakTableFrame
 from math import sqrt
 
+from ccp.lib.MoleculeQuery import getNumConnectingBonds, areResonancesBound, getBoundAtoms
+from ccp.lib.StructureLib import getAtomSetCoords, getAtomSetsDistance
+
 from memops.editor.BasePopup import BasePopup
 from memops.gui.Button import Button
 from memops.gui.ButtonList import UtilityButtonList, ButtonList
