@@ -6,7 +6,7 @@ import subprocess
 import sys
 
 ccpnmr_major = 2
-ccpnmr_minor = 3
+ccpnmr_minor = 4
 ccpnmr_version = '%d.%d' % (ccpnmr_major, ccpnmr_minor)
 
 api_distribution = 'api'
@@ -70,6 +70,8 @@ min_python_version = '2.4'
 #python_release = '2.5.2'
 python_version = '2.6'
 python_release = '2.6.5'
+#python_version = '2.7'
+#python_release = '2.7.6'
 python_rel_dir = 'python%s' % python_version
 python_tar_dir = 'Python-%s' % python_release
 python_tar_file = python_tar_dir + '.tar'
@@ -940,9 +942,9 @@ OPT_FLAG = -O2
 # file flag needed for 32-bit Linux to be able to read > 2Gb files
 BIGFILE_FLAG = %s
 # use below for everything except 32-bit Linux
-BIGFILE_FLAG = 
+#BIGFILE_FLAG = 
 # use below for 32-bit Linux
-BIGFILE_FLAG = -D_FILE_OFFSET_BITS=64
+#BIGFILE_FLAG = -D_FILE_OFFSET_BITS=64
 
 # Some functions utilise OpenMP for multi-cpu optimisation
 # use below if you have more than one cpu
@@ -1864,7 +1866,7 @@ def main(log_file = None):
       addInfoToVersion(softwareDict)
     createSymbolicLinks()
 
-  if py_version in ('2.5', '2.6'):
+  if py_version in ('2.5', '2.6', '2.7'):
     uncommentFutureImport()
 
   if distribution != api_distribution:
